@@ -12,10 +12,6 @@
 
 static	char	*mapterm	(int typ,struct node *val);
 
-#if AMIGA && __SASC
-   extern void PostClip(char *file, int line, int number, char *text);
-#endif				/* AMIGA && __SASC */
-
 /*
  * yyerror produces syntax error messages.  tok is the offending token
  *  (yychar), lval is yylval, and state is the parser's state.
@@ -30,18 +26,12 @@ nodeptr lval;
    {
    register struct errmsg *p;
    int line;
-#ifdef ConsoleWindow
-   extern int silent;
-#endif					/* ConsoleWindow */
 
    if (lval == NULL)
       line = 0;
    else
       line = Line(lval);
 
-#ifdef ConsoleWindow
-   if (!silent) {
-#endif					/* ConsoleWindow */
    if (tok_loc.n_file)
       fprintf(stderr, "File %s; ", tok_loc.n_file);
    if (tok == EOFX)   /* special case end of file */
@@ -52,26 +42,7 @@ nodeptr lval;
          fprintf(stderr, "\"%s\": ", mapterm(tok,lval));
       for (p = errtab; p->e_state != state && p->e_state >= 0; p++) ;
       fprintf(stderr, "%s\n", p->e_mesg);
-#if AMIGA && __SASC
-      if (tok_loc.n_file) PostClip(tok_loc.n_file, line, 0, p->e_mesg);
-#endif				/* AMIGA && __SASC */
       }
-#ifdef ConsoleWindow
-      }
-   else if (flog != NULL) {
-   if (tok_loc.n_file)
-      fprintf(flog, "File %s; ", tok_loc.n_file);
-   if (tok == EOFX)   /* special case end of file */
-      fprintf(flog, "unexpected end of file\n");
-   else {
-      fprintf(flog, "Line %d # ", line);
-      if (Col(lval))
-         fprintf(flog, "\"%s\": ", mapterm(tok,lval));
-      for (p = errtab; p->e_state != state && p->e_state >= 0; p++) ;
-      fprintf(flog, "%s\n", p->e_mesg);
-      }
-      }
-#endif					/* ConsoleWindow */
    tfatals++;
    nocode++;
    }
@@ -115,17 +86,6 @@ char *s1, *s2;
    if (s2)
       fprintf(stderr, "\"%s\": ", s2);
    fprintf(stderr, "%s\n", s1);
-
-#if AMIGA && __SASC
-   if (tok_loc.n_file) {
-      char text[512];
-      if (s2)
-         sprintf(text, "\"%s\": ", s2);
-      strcat(text, s1);
-      PostClip(tok_loc.n_file, tok_loc.n_line, 0, text);
-      }
-#endif				/* AMIGA && __SASC */
-
    tfatals++;
    nocode++;
    }
@@ -146,17 +106,6 @@ char *s1, *s2;
    if (s2)
       fprintf(stderr, "\"%s\": ", s2);
    fprintf(stderr, "%s\n", s1);
-
-#if AMIGA && __SASC
-   if (n != NULL) {
-      char text[512];
-      if (s2)
-         sprintf(text, "\"%s\": ", s2);
-      strcat(text, s1);
-      PostClip(File(n), Line(n), 0, text);
-      }
-#endif				/* AMIGA && __SASC */
-
    tfatals++;
    nocode++;
    }
@@ -212,20 +161,19 @@ char *msg;
 void quitf(msg,arg)
 char *msg, *arg;
    {
-
-
    extern char *progname;
+
    fprintf(stderr,"%s: ",progname);
    fprintf(stderr,msg,arg);
    fprintf(stderr,"\n");
 
-#if !defined(VarTran) && !defined(Iconc)
-   {
+   #if !defined(Iconc)
+      {
       extern char *ofile;
       if (ofile)
 	 remove(ofile);			/* remove bad icode file */
-   }
-#endif					/* !VarTran && !Iconc */
+      }
+   #endif				/* !Iconc */
 
    exit(EXIT_FAILURE);
    }
