@@ -10,34 +10,17 @@ typedef struct {
   int i;
 } stringint, *siptr;
 
-#if !VMS
-   #undef VMS
-#endif					/* VMS */
+#ifdef XpmFormat
+   #include "../xpm/xpm.h"
+#else					/* XpmFormat */
+   #include <X11/Xlib.h>
+   #include <X11/Xutil.h>
+#endif					/* XpmFormat */
 
-#if VMS
-   #undef UNIX
-   #ifdef XpmFormat
-      #include "../xpm/xpm.h"
-   #endif				/* XpmFormat */
-   #include "decw$include:Xlib.h"
-   #include "decw$include:Xutil.h"
-   #include "decw$include:Xos.h"
-   #include "decw$include:Xatom.h"
-   #include "decw$include:cursorfont.h"
-   #include "decw$include:keysym.h"
-   #define UNIX 0
-#else					/* VMS */
-   #ifdef XpmFormat
-      #include "../xpm/xpm.h"
-   #else				/* XpmFormat */
-      #include <X11/Xlib.h>
-      #include <X11/Xutil.h>
-   #endif				/* XpmFormat */
-   #include <X11/Xos.h>
-   #include <X11/Xatom.h>
-   #include <X11/cursorfont.h>
-   #include <X11/keysym.h>
-#endif					/* VMS */
+#include <X11/Xos.h>
+#include <X11/Xatom.h>
+#include <X11/cursorfont.h>
+#include <X11/keysym.h>
 
 int GraphicsHome  = XK_Home;
 int GraphicsLeft  = XK_Left;
@@ -69,7 +52,6 @@ KeySym *k;
       return 0;			/* other (e.g. function key) */
 }
 
-
 stringint drawops[] = {
    { 0, 16},
    {"and",		GXand},
@@ -174,6 +156,4 @@ stringint cursorsyms[] = {
   {"num glyphs",	XC_num_glyphs},
 };
 
-#else					/* XWindows */
-  static char x;
 #endif					/* XWindows */
