@@ -7,9 +7,9 @@
  * is defined.
  */
 
-#if !defined(Iconc) && !defined(VarTran)
+#if !defined(Iconc)
    #include "../h/esctab.h"
-#endif					/* !Iconc && !VarTran */
+#endif					/* !Iconc */
 
 /*
  * Prototypes.
@@ -23,21 +23,14 @@ static	struct toktab   *getstring	(int ac,int *cc);
 static	int		setfilenm	(int c);
 static	int		setlineno	(void);
 
-#if !defined(Iconc) && !defined(VarTran)
+#if !defined(Iconc)
    static	int	ctlesc		(void);
    static	int	hexesc		(void);
    static	int	octesc		(int ac);
-#endif					/* !Iconc && !VarTran */
+#endif					/* !Iconc */
 
 #define isletter(s)	(isupper(c) | islower(c))
-
-#if EBCDIC
-   extern char ToEBCDIC[256], FromEBCDIC[256];
-#endif					/* EBCDIC */
-
-#if !EBCDIC
-   #define tonum(c)        (isdigit(c) ? (c - '0') : ((c & 037) + 9))
-#endif					/* !EBCDIC */
+#define tonum(c)        (isdigit(c) ? (c - '0') : ((c & 037) + 9))
 
 struct node tok_loc =
    {0, NULL, 0, 0};	/* "model" node containing location of current token */
@@ -199,19 +192,6 @@ ret:
    return (t->t_type);
    }
 
-#ifdef MultipleRuns
-/*
- * yylexinit - initialize variables for multiple runs
- */
-void yylexinit()
-   {
-   lasttok = NULL;
-   lastend = 0;
-   eofflag = 0;
-   cc = '\n';
-   }
-#endif					/* MultipleRuns */
-
 /*
  * getident - gather an identifier beginning with ac.  The character
  *  following identifier goes in cc.
@@ -420,7 +400,7 @@ int *cc;
          if (c == EOF)
             break;
 
-#if defined(Iconc) || defined(VarTran)
+#if defined(Iconc)
          AppChar(lex_sbuf, Escape);
          if (c == '^') {
             c = NextChar;
@@ -428,7 +408,7 @@ int *cc;
                break;
             AppChar(lex_sbuf, '^');
             }
-#else					/* Iconc || VarTran */
+#else					/* Iconc */
 	 if (isoctal(c))
 	    c = octesc(c);
 	 else if (c == 'x')
@@ -437,7 +417,7 @@ int *cc;
 	    c = ctlesc();
 	 else
 	    c = esctab[c];
-#endif					/* Iconc || VarTran */
+#endif					/* Iconc */
 
 	 }
       AppChar(lex_sbuf, c);
@@ -471,7 +451,7 @@ int *cc;
       }
    }
 
-#if !defined(Iconc) && !defined(VarTran)
+#if !defined(Iconc)
 
 /*
  * ctlesc - translate a control escape -- backslash followed by
@@ -486,14 +466,7 @@ static int ctlesc()
    if (c == EOF)
       return EOF;
 
-#if !EBCDIC
    return (c & 037);
-#else					/* !EBCDIC */
-   return ToEBCDIC[FromEBCDIC[c] & 037];
-                        /* ctrl-x in EBCDIC is the EBCDIC equivalent */
-                        /* to ASCII ctrl-x                           */
-#endif					/* !EBCDIC */
-
    }
 
 /*
@@ -517,11 +490,7 @@ int ac;
       } while (isoctal(nc) && i++ < 3);
    PushChar(nc);
 
-#if EBCDIC != 2
    return (c & 0377);
-#else					/* EBCDIC != 2 */
-   return ToEBCDIC[c & 0377];
-#endif					/* EBCDIC != 2 */
    }
 
 /*
@@ -552,15 +521,10 @@ static int hexesc()
       c = (c << 4) | nc;
       }
 
-#if EBCDIC != 2
    return c;
-#else					/* EBCDIC != 2 */
-   return ToEBCDIC[c];
-#endif					/* EBCDIC != 2 */
-
    }
 
-#endif					/* !Iconc && !VarTran */
+#endif					/* !Iconc */
 
 /*
  * setlineno - set line number from #line comment, return following char.
@@ -623,18 +587,6 @@ int nextchar()
    {
    register int c;
 
-#if MACINTOSH
-#if MPW
-   {
-   static short cursorcount = CURSORINTERVAL;
-   if (--cursorcount == 0) {
-      RotateCursor(0);
-      cursorcount = CURSORINTERVAL;
-      }
-   }
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
    if ((c = peekc) != 0) {
       peekc = 0;
       return c;
