@@ -15,8 +15,8 @@
 /*
  * Most of the present implementations use 32-bit "words".  Note that
  *  WordBits is the number of bits in an Icon integer, not necessarily
- *  the number of bits in an int (given by IntBits).  For example,
- *  in MS-DOS an Icon integer is a long, not an int.
+ *  the number of bits in an int (given by IntBits).  In some systems
+ *  an Icon integer is a long, not an int.
  *
  *  MaxStrLen must not be so large as to overlap flags.
  */
@@ -26,21 +26,21 @@
  */
 
 #if WordBits == 64
-   
+
    #ifndef MinLong
       #define MinLong  ((long int)0x8000000000000000) /* smallest long int */
    #endif
-   
+
    #ifndef MaxLong
       #define MaxLong  ((long int)0x7fffffffffffffff) /* largest long integer */
    #endif
-   
+
    #define MaxStrLen 017777777777L		/* maximum string length */
-   
+
    #ifndef MaxNegInt
       #define MaxNegInt "-9223372036854775808"
    #endif
-   
+
    #ifndef F_Nqual
       #define F_Nqual 0x8000000000000000	/* set if NOT string qualifier*/
    #endif				/* F_Nqual */
@@ -56,7 +56,7 @@
    #ifndef F_Typecode
       #define F_Typecode  0x2000000000000000	/* set if dword incls typecode*/
    #endif				/* F_Typecode */
-   
+
 #endif					/* WordBits == 64 */
 
 /*
@@ -64,14 +64,14 @@
  */
 
 #if WordBits == 32
-   
+
    #define MaxLong  ((long int)017777777777L)   /* largest long integer */
    #define MinLong  ((long int)020000000000L)   /* smallest long integer */
-   
+
    #define MaxNegInt "-2147483648"
-   
+
    #define MaxStrLen 0777777777		/* maximum string length */
-   
+
    #define F_Nqual	0x80000000	/* set if NOT string qualifier */
    #define F_Var	0x40000000	/* set if variable */
    #define F_Ptr	0x10000000	/* set if value field is pointer */
@@ -92,10 +92,10 @@
     * Cset initialization and access macros.
     */
    #define fwd(w0, w1, w2, w3) \
-    (((w0)&0xffff) | (((unsigned)(w1)&0xffff)<<16) | \
-    (((unsigned)(w2)&0xffff)<<32) | (((unsigned)(w3)&0xffff)<<48))
+      (((w0) & 0xffff) | (((unsigned)(w1) & 0xffff) << 16) | \
+      (((unsigned)(w2) & 0xffff) << 32) | (((unsigned)(w3) & 0xffff) << 48))
    #define cset_display(w0,w1,w2,w3,w4,w5,w6,w7,w8,w9,wa,wb,wc,wd,we,wf) \
-    {fwd(w0,w1,w2,w3),fwd(w4,w5,w6,w7),fwd(w8,w9,wa,wb),fwd(wc,wd,we,wf)}
+      {fwd(w0,w1,w2,w3),fwd(w4,w5,w6,w7),fwd(w8,w9,wa,wb),fwd(wc,wd,we,wf)}
    #define Cset32(b,c) (*CsetPtr(b,c)>>(32*CsetOff((b)>>5)))  /* 32b of cset */
 #endif					/* IntBits == 64 */
 
@@ -113,24 +113,6 @@
    #define Cset32(b,c) (*CsetPtr(b,c))	/* 32 bits of cset */
 #endif					/* IntBits == 32 */
 
-#if IntBits == 16
-   #define LogIntBits	4			/* log of IntBits */
-   #define MaxUnsigned ((unsigned int)0177777)	/* largest unsigned integer */
-   #define MaxInt	077777			/* largest int */
-   
-   #ifndef MaxListSlots
-      #define MaxListSlots 8000		/* largest list-element block */
-   #endif				/* MaxListSlots */
-   
-   /*
-    * Cset initialization and access macros.
-    */
-   #define cset_display(w0,w1,w2,w3,w4,w5,w6,w7,w8,w9,wa,wb,wc,wd,we,wf) \
-      {w0,w1,w2,w3,w4,w5,w6,w7,w8,w9,wa,wb,wc,wd,we,wf}
-   #define Cset32(b,c) (((unsigned long)(unsigned int)(*CsetPtr((b)+16,c))<<16) | \
-      ((unsigned long)(unsigned int)(*CsetPtr(b,c))))  /* 32 bits of cset */
-#endif					/* IntBits == 16 */
-
 #ifndef LogHuge
    #define LogHuge 309			/* maximum base-10 exp+1 of real */
 #endif					/* LogHuge */
@@ -152,7 +134,7 @@
  *  HSegs	Maximum number of hash bin segments; the maximum number of
  *		hash bins is HSlots * 2 ^ (HSegs - 1).
  *
- *		If Hsegs is increased above 12, the arrays log2h[] and segsize[]
+ *		If Hsegs is increased above 20, the arrays log2h[] and segsize[]
  *		in the runtime system will need modification.
  *
  *  MaxHLoad	Maximum loading factor; more hash bins are allocated when
@@ -166,25 +148,16 @@
  */
 
 #ifndef HSlots
-   #if IntBits == 16
-      #define HSlots     4
-      #define LogHSlots  2
-   #else				/* IntBits */
-      #define HSlots     8
-      #define LogHSlots  3
-   #endif				/* IntBits */
+   #define HSlots     16
+   #define LogHSlots  4
 #endif					/* HSlots */
 
 #if ((1 << LogHSlots) != HSlots)
-   Deliberate Syntax Error -- HSlots and LogHSlots are inconsistent
+   #error HSlots and LogHSlots are inconsistent
 #endif					/* HSlots / LogHSlots consistency */
 
 #ifndef HSegs
-   #if IntBits == 16
-      #define HSegs	  6
-   #else				/* IntBits */
-      #define HSegs	 10
-   #endif				/* IntBits */
+   #define HSegs	 20
 #endif					/* HSegs */
 
 #ifndef MinHLoad
@@ -211,7 +184,7 @@
 #define MaxDigits	30
 
 /*
- * Memory sizing. 
+ * Memory sizing.
  */
 #ifndef AlcMax
    #define AlcMax 25
@@ -221,11 +194,7 @@
  * Maximum sized block that can be allocated (via malloc() or such).
  */
 #ifndef MaxBlock
-   #if IntBits == 16
-      #define MaxBlock 65000		/* leaves room for malloc header */
-   #else				/* IntBits == 16 */
-      #define MaxBlock MaxUnsigned
-   #endif				/* IntBits == 16 */
+   #define MaxBlock MaxUnsigned
 #endif					/* MaxBlock */
 
 /*
@@ -234,21 +203,17 @@
  */
 
 #ifndef MaxStrSpace
-   #if IntBits == 16
-      #define MaxStrSpace 65000		/* size of the string space in bytes */
-   #else				/* IntBits == 16 */
-      #define MaxStrSpace 500000	/* size of the string space in bytes */
-   #endif				/* IntBits == 16 */
+   #define MaxStrSpace 500000		/* size of the string space in bytes */
 #endif					/* MaxStrSpace */
 
 #ifndef MaxAbrSize
-   #if IntBits == 16
-      #define MaxAbrSize 65000		/* size of the block region in bytes */
-   #else				/* IntBits == 16 */
-      #define MaxAbrSize 500000		/* size of the block region in bytes */
-   #endif				/* IntBits == 16 */
+   #define MaxAbrSize 500000		/* size of the block region in bytes */
 #endif					/* MaxAbrSize */
 
+#ifndef MinAbrSize
+   #define MinAbrSize	 5000		/* minimum block region size */
+#endif					/* MinAbrSize */
+
 #ifndef MStackSize
    #ifdef MultiThread
       #define MStackSize 20000		/* size of the main stack in words */
@@ -280,42 +245,3 @@
 #ifndef RegionGrowth
    #define RegionGrowth 200		/* % region growth when full */
 #endif					/* RegionGrowth */
-
-/*
- * Minimum regions sizes (presently not used).
- */
-#ifndef MinStatSize
-   #ifdef Coexpr
-      #define MinStatSize	10240	/* size of the static region in bytes*/
-   #else				/* Coexpr */
-      #define MinStatSize	 1024	/* size of static region in bytes */
-   #endif				/* Coexpr */
-#endif					/* MinStatSize */
-
-#ifndef MinStrSpace
-   #define MinStrSpace		 5000	/* size of the string space in bytes */
-#endif					/* MinStrSpace */
-
-#ifndef MinAbrSize
-   #define MinAbrSize		 5000	/* size of the block region in bytes */
-#endif					/* MinAbrSize */
-
-#ifndef MinMStackSize
-   #define MinMStackSize	 2000	/* size of the main stack in words */
-#endif					/* MinMStackSize */
-
-#ifndef MinStackSize
-   #define MinStackSize		 1000	/* words in co-expression stack */
-#endif					/* MinStackSize */
-
-#ifndef MinQualLstSize
-   #define MinQualLstSize	  500	/* size of qualifier pointer region */
-#endif					/* MinQualLstSize */
-
-#ifndef GranSize
-   #define GranSize		   64	/* storage allocation granule size */
-#endif					/* GranSize */
-
-#ifndef Sqlinc
-   #define Sqlinc 128*sizeof(dptr *)	/* qualifier pointer list increment */
-#endif					/* Sqlinc */
