@@ -117,13 +117,6 @@ FncDefV(writes)
    FncDefV(callout)
 #endif					/* ExternalFunctions */
 
-/*
- * Executable images.
- */
-#ifdef ExecImages
-   FncDef(save,1)
-#endif					/* ExecImages */
-
 /*
  * File attribute function.
  */
