@@ -4,6 +4,7 @@
  *   does not output any code from them.
  */
 #include "../h/define.h"
+#include "../h/arch.h"
 #include "../h/config.h"
 #include "../h/version.h"
 
@@ -78,7 +79,7 @@
 #begdef EVVal(value,event)
    do {
       if (is:null(curpstate->eventmask)) break;
-      else if (!Testb((word)ToAscii(event), curpstate->eventmask)) break;
+      else if (!Testb((word)event, curpstate->eventmask)) break;
       MakeInt(value, &(curpstate->parent->eventval));
       actparent(event);
    } while (0)
@@ -86,7 +87,7 @@
 #begdef EVValD(dp,event)
    do {
       if (is:null(curpstate->eventmask)) break;
-      else if (!Testb((word)ToAscii(event), curpstate->eventmask)) break;
+      else if (!Testb((word)event, curpstate->eventmask)) break;
       curpstate->parent->eventval = *(dp);
       actparent(event);
    } while (0)
@@ -95,40 +96,16 @@
    do {
       struct progstate *parent = curpstate->parent;
       if (is:null(curpstate->eventmask)) break;
-      else if (!Testb((word)ToAscii(event), curpstate->eventmask)) break;
+      else if (!Testb((word)event, curpstate->eventmask)) break;
       parent->eventval.dword = D_Coexpr;
       BlkLoc(parent->eventval) = (union block *)(bp);
       actparent(event);
    } while (0)
 #enddef					/* EVValX */
 
-#if UNIX
-   #begdef EVTick()
-   /*
-    * EVTick() - record a Tick event reflecting a clock advance.
-    *
-    *  The interpreter main loop has detected a change in the profile counters.
-    *  This means that the system clock has ticked.  Record an event and update
-    *  the records.
-    */
-   do {
-      word sum, nticks;
-
-      oldtick = ticker.l[0] + ticker.l[1];
-      sum = ticker.s[0] + ticker.s[1] + ticker.s[2] + ticker.s[3];
-      nticks = sum - oldsum;
-      EVVal(nticks, E_Tick);
-      oldsum = sum;
-   } while (0)
-   #enddef				/* EVTick */
-#else					/* UNIX */
-   #define EVTick()
-#endif					/* UNIX */
-
 #define InterpEVVal(arg1,arg2)  { ExInterp; EVVal(arg1,arg2); EntInterp; }
 #define InterpEVValD(arg1,arg2) { ExInterp; EVValD(arg1,arg2); EntInterp; }
 #define InterpEVValX(arg1,arg2) { ExInterp; EVValX(arg1,arg2); EntInterp; }
-#define InterpEVTick()          { ExInterp; EVTick(); EntInterp; }
 
 /*
  * Macro with construction of event descriptor.
@@ -146,11 +123,9 @@
    #define EVVal(arg1,arg2)
    #define EVValD(arg1,arg2)
    #define EVValX(arg1,arg2)
-   #define EVTick()
    #define InterpEVVal(arg1,arg2)
    #define InterpEVValD(arg1,arg2)
    #define InterpEVValX(arg1,arg2)
-   #define InterpEVTick()
    #define Desc_EVValD(bp, code, type)
 #endif					/* EventMon */
 
@@ -159,14 +134,6 @@
  */
 typedef int clock_t, time_t, fd_set;
 
-#if OS2_32
-   typedef int HFILE, ULONG;
-#endif					/* OS2_32 */
-
-#if WildCards
-   typedef int FINDDATA_T;
-#endif					/* WildCards */
-
 #ifdef ReadDirectory
    typedef int DIR;
 #endif					/* ReadDirectory */
@@ -181,15 +148,6 @@ typedef int clock_t, time_t, fd_set;
    typedef int XRectangle, XPoint, XSegment, XArc, SysColor, LinearColor;
    typedef int LONG, SHORT;
 
-   #ifdef MacGraph
-      typedef int Str255, Point, StandardFileReply, SFTypeList, Ptr, PixMap;
-      typedef int Boolean, Rect, PolyHandle, EventRecord, wsp, MouseInfoType;
-      typedef int Handle, MenuHandle, OSErr, WindowPtr, GWorldFlags;
-      typedef int PaletteHandle, BitMap, RgnHandle, QDErr, GWorldPtr;
-      typedef int GrafPtr, GDHandle, PixMapHandle, OSType, FInfo;
-      typedef int IOParam, DialogPtr, ControlHandle, StringHandle, Size;
-   #endif				/* MacGraph */
-
    #ifdef XWindows
       typedef int Atom, Time, XSelectionEvent, XErrorEvent, XErrorHandler;
       typedef int XGCValues, XColor, XFontStruct, XWindowAttributes, XEvent;
@@ -199,8 +157,8 @@ typedef int clock_t, time_t, fd_set;
       typedef int *Display, Cursor, GC, Window, Pixmap, Visual, KeySym;
       typedef int WidgetClass, XImage, XpmAttributes;
    #endif				/* XWindows */
-      
-   #ifdef MSWindows
+
+   #ifdef WinGraphics
       typedef int clock_t, jmp_buf, MINMAXINFO, OSVERSIONINFO, BOOL_CALLBACK;
       typedef int int_PASCAL, LRESULT_CALLBACK, MSG, BYTE, WORD, DWORD;
       typedef int HINSTANCE, LPSTR, HBITMAP, WNDCLASS, PAINTSTRUCT, POINT, RECT;
@@ -211,53 +169,33 @@ typedef int clock_t, time_t, fd_set;
       typedef int MCI_OPEN_PARMS, MCI_STATUS_PARMS, MCI_SEQ_SET_PARMS;
       typedef int CHOOSEFONT, CHOOSECOLOR, OPENFILENAME, HMENU, LPBITMAPINFO;
       typedef int childcontrol, CPINFO, BITMAPINFO, BITMAPINFOHEADER, RGBQUAD;
-      #ifdef FAttrib
-         typedef unsigned long mode_t;
-         typedef int HFILE, OFSTRUCT, FILETIME, SYSTEMTIME;
-      #endif				/* FAttrib */
-   #endif				/* MSWindows */
-
-   #ifdef PresentationManager
-      /* OS/2 PM specifics */
-      typedef int HAB, HPS, QMSG, HMQ, HWND, USHORT, MRESULT, ULONG, MPARAM;
-      typedef int PFNWP, HMODULE, SHORT, BOOL, TID, RECTL, ERRORID;
-      typedef int MRESULT_N_EXPENTRY, SIZEL, HDC, POINTL, HMTX, HBITMAP;
-      typedef int VOID_APIENTRY, UCHAR, HEV, LINEBUNDLE, BUTMAPARRAYFILEHEADER;
-      typedef int LONG, BITMAPINFOHEADER2, PBITMAPINFO2, PSZ, RGB2, BITMAPINFO2;
-      typedef int FONTMETRICS, PRECTL, PCHARBUNDLE, PLINEBUNDLE, PIMAGEBUNDLE;
-      typedef int AREABUNDLE, PAREABUNDLE, PPOINTL, POLYGON, CHARBUNDLE;
-      typedef int lclIdentifier, BYTE, PBYTE, PRGB2, FATTRS, PFATTRS, PULONG;
-      typedef int PBITMAPINFOHEADER2, BITMAPFILEHEADER2, BITMAPARRAYFILEHEADER2;
-      typedef int colorEntry, ARCPARAMS, threadargs, HPOINTER, CURSORINFO;
-      typedef int PCURSORINFO, DEVOPENSTRUCT, PDEVOPENDATA, SIZEF, HRGN, PSWP;
-      typedef int va_list, BITMAPINFOHEADER, BITMAPFILEHEADER;
-      typedef int PBITMAPINFOHEADER, MinBitmapHeader, RGB;
-   #endif				/* PresentationManager */
+      typedef int BOOL, LPMSG, STARTUPINFO;
+   #endif				/* WinGraphics */
 
    /*
     * Convenience macros to make up for RTL's long-windedness.
     */
    #begdef CnvCShort(desc, s)
-	{
-	C_integer tmp;
-	if (!cnv:C_integer(desc,tmp) || tmp > 0x7FFF || tmp < -0x8000)
-	   runerr(101,desc);
-	s = (short) tmp;
-	}
+      {
+      C_integer tmp;
+      if (!cnv:C_integer(desc,tmp) || tmp > 0x7FFF || tmp < -0x8000)
+         runerr(101,desc);
+      s = (short) tmp;
+      }
    #enddef				/* CnvCShort */
-   
+
    #define CnvCInteger(d,i) \
-     if (!cnv:C_integer(d,i)) runerr(101,d);
-   
+      if (!cnv:C_integer(d,i)) runerr(101,d);
+
    #define DefCInteger(d,default,i) \
-     if (!def:C_integer(d,default,i)) runerr(101,d);
-   
+      if (!def:C_integer(d,default,i)) runerr(101,d);
+
    #define CnvString(din,dout) \
-     if (!cnv:string(din,dout)) runerr(103,din);
-   
+      if (!cnv:string(din,dout)) runerr(103,din);
+
    #define CnvTmpString(din,dout) \
-     if (!cnv:tmp_string(din,dout)) runerr(103,din);
-   
+      if (!cnv:tmp_string(din,dout)) runerr(103,din);
+
    /*
     * conventions supporting optional initial window arguments:
     *
@@ -270,39 +208,39 @@ typedef int clock_t, time_t, fd_set;
    #begdef OptWindow(w)
       if (argc>warg && is:file(argv[warg])) {
          if ((BlkLoc(argv[warg])->file.status & Fs_Window) == 0)
-	    runerr(140,argv[warg]);
+            runerr(140,argv[warg]);
          if ((BlkLoc(argv[warg])->file.status & (Fs_Read|Fs_Write)) == 0)
-	    runerr(142,argv[warg]);
+            runerr(142,argv[warg]);
          (w) = (wbp)BlkLoc(argv[warg])->file.fd;
          if (ISCLOSED(w))
-	    runerr(142,argv[warg]);
+            runerr(142,argv[warg]);
          warg++;
          }
       else {
          if (!(is:file(kywd_xwin[XKey_Window]) &&
-	      (BlkLoc(kywd_xwin[XKey_Window])->file.status & Fs_Window)))
-	    runerr(140,kywd_xwin[XKey_Window]);
-         if (!(BlkLoc(kywd_xwin[XKey_Window])->file.status & (Fs_Read|Fs_Write)))
-	    runerr(142,kywd_xwin[XKey_Window]);
+            (BlkLoc(kywd_xwin[XKey_Window])->file.status & Fs_Window)))
+               runerr(140,kywd_xwin[XKey_Window]);
+         if (!(BlkLoc(kywd_xwin[XKey_Window])->file.status&(Fs_Read|Fs_Write)))
+            runerr(142,kywd_xwin[XKey_Window]);
          (w) = (wbp)BlkLoc(kywd_xwin[XKey_Window])->file.fd;
          if (ISCLOSED(w))
-	    runerr(142,kywd_xwin[XKey_Window]);
+            runerr(142,kywd_xwin[XKey_Window]);
          }
    #enddef				/* OptWindow */
-   
+
    #begdef ReturnWindow
          if (!warg) return kywd_xwin[XKey_Window];
          else return argv[0]
    #enddef				/* ReturnWindow */
-   
+
    #begdef CheckArgMultiple(mult)
-   {
-     if ((argc-warg) % (mult)) runerr(146);
-     n = (argc-warg)/mult;
-     if (!n) runerr(146);
-   }
+      {
+      if ((argc-warg) % (mult)) runerr(146);
+      n = (argc-warg)/mult;
+      if (!n) runerr(146);
+      }
    #enddef				/* CheckArgMultiple */
-   
+
    /*
     * calloc to make sure uninit'd entries are zeroed.
     */
@@ -313,7 +251,7 @@ typedef int clock_t, time_t, fd_set;
          var->refcount = 1;
       } while(0)
    #enddef				/* GRFX_ALLOC */
-   
+
    #begdef GRFX_LINK(var, chain)
       do {
          var->next = chain;
@@ -322,7 +260,7 @@ typedef int clock_t, time_t, fd_set;
          chain = var;
       } while(0)
    #enddef				/* GRFX_LINK */
-   
+
    #begdef GRFX_UNLINK(var, chain)
       do {
          if (var->previous) var->previous->next = var->next;
@@ -331,5 +269,10 @@ typedef int clock_t, time_t, fd_set;
          free(var);
       } while(0)
    #enddef				/* GRFX_UNLINK */
-   
+
 #endif					/* Graphics */
+
+#ifdef FAttrib
+   typedef unsigned long mode_t;
+   typedef int HFILE, OFSTRUCT, FILETIME, SYSTEMTIME;
+#endif					/* FAttrib */
