@@ -33,7 +33,6 @@
 #define LINEWIDTH(w) ((w)->context->pen.lopnWidth.x)
 #define DISPLAYHEIGHT(w) devicecaps(w, VERTRES)
 #define DISPLAYWIDTH(w) devicecaps(w, HORZRES)
-#define wflush(w) 0 /* noop */
 #define wsync(w) /* noop */
 #define SysColor unsigned long
 #define RED(x) GetRValue(x)
@@ -62,7 +61,7 @@
 #define ICONLABEL(w) ((w)->window->iconlabel)
 #define WINDOWLABEL(w) ((w)->window->windowlabel)
 
-#define MAXDESCENDER(w) 0
+#define MAXDESCENDER(w) DESCENT(w)
 
 /*
  * gemeotry bitmasks
@@ -88,6 +87,11 @@
 #define WS_MIN               1
 #define WS_MAX               2
 
+/*
+ * input masks
+ */
+#define PointerMotionMask    1
+
 /*
  * something I think should be #defined
  */
@@ -190,7 +194,7 @@ typedef struct {
 #define STDFONT \
    { if(stdwin)SelectObject(stddc, wc->font->font); SelectObject(pixdc,wc->font->font); }
 
-#define FREE_STDLOCALS(w) ReleaseDC((w)->window->iconwin, stddc); DeleteDC(pixdc);
+#define FREE_STDLOCALS(w) do { SelectObject(pixdc, (w)->window->theOldPix); ReleaseDC((w)->window->iconwin, stddc); DeleteDC(pixdc); } while (0)
 
 #define MAXXOBJS 8
 
