@@ -1,6 +1,6 @@
 /*
  * Operator definitions.
- *  
+ *
  * Fields are:
  *    name
  *    number of arguments
@@ -28,7 +28,7 @@ OpDef(mod,2,"%",0)
 OpDef(mult,2,"*",0)
 OpDef(neg,1,"-",0)
 OpDef(neqv,2,"~===",0)
-OpDef(nonnull,1,BackSlash,-1)
+OpDef(nonnull,1,"\\",-1)
 OpDef(null,1,"/",-1)
 OpDef(number,1,"+",0)
 OpDef(numeq,2,"=",0)
