@@ -6,11 +6,12 @@
  */
 
 #include "../h/define.h"
+#include "../h/arch.h"
 #include "../h/config.h"
 #include "../h/sys.h"
 #include "../h/typedefs.h"
 #include "../h/cstructs.h"
-#include "../h/proto.h"
+#include "../h/mproto.h"
 #include "../h/cpuconf.h"
 #include "../h/monitor.h"
 #include "../h/rmacros.h"
