@@ -1,7 +1,6 @@
 /*
  * codegen.c - routines to write out C code.
  */
-#include <ctype.h>
 #include "../h/gsupport.h"
 #include "ctrans.h"
 #include "cglobals.h"
@@ -41,30 +40,30 @@
 /*
  * Prototypes for static functions.
  */
-hidden int     arg_nms   Params((struct lentry *lptr, int prt));
-hidden novalue bi_proc   Params((char *name, struct implement *ip));
-hidden novalue chkforgn  Params((int outer));
-hidden int     dyn_nms   Params((struct lentry *lptr, int prt));
-hidden novalue fldnames  Params((struct fldname *fields));
-hidden novalue fnc_blk   Params((struct gentry *gptr));
-hidden novalue frame     Params((int outer));
-hidden novalue good_clsg Params((struct code *call, int outer));
-hidden novalue initpblk  Params((FILE *f, int c, char *prefix, char *name,
+static int     arg_nms   (struct lentry *lptr, int prt);
+static void bi_proc   (char *name, struct implement *ip);
+static void chkforgn  (int outer);
+static int     dyn_nms   (struct lentry *lptr, int prt);
+static void fldnames  (struct fldname *fields);
+static void fnc_blk   (struct gentry *gptr);
+static void frame     (int outer);
+static void good_clsg (struct code *call, int outer);
+static void initpblk  (FILE *f, int c, char *prefix, char *name,
                            int nquals, int nparam, int ndynam, int nstatic,
-                           int frststat));
-hidden char  *is_builtin Params((struct gentry *gptr));
-hidden novalue proc_blk  Params((struct gentry *gptr, int init_glbl));
-hidden novalue prt_ary   Params((struct code *cd, int outer));
-hidden novalue prt_cond  Params((struct code *cond));
-hidden novalue prt_cont  Params((struct c_fnc *cont));
-hidden novalue prt_var   Params((struct lentry *var, int outer));
-hidden novalue prtcall   Params((struct code *call, int outer));
-hidden novalue prtcode   Params((struct code *cd, int outer));
-hidden novalue prtpccall Params((int outer));
-hidden novalue rec_blk   Params((struct gentry *gptr, int init_glbl));
-hidden novalue smpl_clsg Params((struct code *call, int outer));
-hidden novalue stat_nms  Params((struct lentry *lptr, int prt));
-hidden novalue val_loc   Params((struct val_loc *rslt, int outer));
+                           int frststat);
+static char  *is_builtin (struct gentry *gptr);
+static void proc_blk  (struct gentry *gptr, int init_glbl);
+static void prt_ary   (struct code *cd, int outer);
+static void prt_cond  (struct code *cond);
+static void prt_cont  (struct c_fnc *cont);
+static void prt_var   (struct lentry *var, int outer);
+static void prtcall   (struct code *call, int outer);
+static void prtcode   (struct code *cd, int outer);
+static void prtpccall (int outer);
+static void rec_blk   (struct gentry *gptr, int init_glbl);
+static void smpl_clsg (struct code *call, int outer);
+static void stat_nms  (struct lentry *lptr, int prt);
+static void val_loc   (struct val_loc *rslt, int outer);
 
 static int n_stat = -1;		/* number of static variables */
 
@@ -74,7 +73,7 @@ static int n_stat = -1;		/* number of static variables */
  *  frames, record blocks, declarations for globals and statics, the
  *  C main program.
  */
-novalue var_dcls()
+void var_dcls()
    {
    register int i;
    register struct gentry *gptr;
@@ -295,7 +294,7 @@ novalue var_dcls()
          "   P%s_main(1, &t.arg_lst, &trashcan, (continuation)NULL);\n",
          prc_main->prefix);
    fprintf(codefile, "   \n");
-   fprintf(codefile, "   c_exit(NormalExit);\n");
+   fprintf(codefile, "   c_exit(EXIT_SUCCESS);\n");
    fprintf(codefile, "   }\n");
 
    /*
@@ -329,7 +328,7 @@ novalue var_dcls()
  * proc_blk - create procedure block and initialize global variable, also
  *   compute offsets for local procedure variables.
  */
-static novalue proc_blk(gptr, init_glbl)
+static void proc_blk(gptr, init_glbl)
 struct gentry *gptr;
 int init_glbl;
    {
@@ -348,9 +347,9 @@ int init_glbl;
       fprintf(codefile, "(union block *)&BP%s_%s},\n", p->prefix, name);
       nquals = 1 + Abs(p->nargs) + p->ndynam + p->nstatic;
       fprintf(inclfile, "\n");
-      fprintf(inclfile, "hidden int P%s_%s Params((int r_nargs, dptr r_args,",
+      fprintf(inclfile, "static int P%s_%s (int r_nargs, dptr r_args,",
          p->prefix, name);
-      fprintf(inclfile, "dptr r_rslt, continuation r_s_cont));\n");
+      fprintf(inclfile, "dptr r_rslt, continuation r_s_cont);\n");
       initpblk(inclfile, 'P', p->prefix, name, nquals, p->nargs, p->ndynam,
          p->nstatic, n_stat + 1);
       fprintf(inclfile, "\n   {%d, \"%s\"},\n", strlen(name), name);
@@ -404,7 +403,7 @@ int prt;
  * stat_nams - compute offsets of static locals and, if needed, output the
  *  initializer for a descriptor for the variable name.
  */
-static novalue stat_nms(lptr, prt)
+static void stat_nms(lptr, prt)
 struct lentry *lptr;
 int prt;
    {
@@ -440,7 +439,7 @@ struct gentry *gptr;
  * fnc_blk - output vword of descriptor for a built-in function and its
  *   procedure block.
  */
-static novalue fnc_blk(gptr)
+static void fnc_blk(gptr)
 struct gentry *gptr;
    {
    struct implement *iptr;
@@ -462,7 +461,7 @@ struct gentry *gptr;
 /*
  * bi_proc - output prototype and procedure block for builtin function.
  */
-static novalue bi_proc(name, ip)
+static void bi_proc(name, ip)
 char *name;
    struct implement *ip;
    {
@@ -485,7 +484,7 @@ char *name;
  * rec_blk - if needed, output vword of descriptor for a record
  *   constructor and output its procedure block.
  */
-static novalue rec_blk(gptr, init_glbl)
+static void rec_blk(gptr, init_glbl)
 struct gentry *gptr;
 int init_glbl;
    {
@@ -510,11 +509,11 @@ int init_glbl;
     *   are used and we need a continuation parameter.
     */
    fprintf(inclfile,
-      "hidden int R%s_%s Params((int r_nargs, dptr r_args, dptr r_rslt",
+      "static int R%s_%s (int r_nargs, dptr r_args, dptr r_rslt",
       r->prefix, name);
    if (init_glbl)
       fprintf(inclfile, ", continuation r_s_cont");
-   fprintf(inclfile, "));\n");
+   fprintf(inclfile, ");\n");
 
    /*
     * Procedure block, including record name and field names.
@@ -530,7 +529,7 @@ int init_glbl;
 /*
  * fldnames - output the initializer for a descriptor for the field name.
  */
-static novalue fldnames(fields)
+static void fldnames(fields)
 struct fldname *fields;
    {
    register char *name;
@@ -545,22 +544,22 @@ struct fldname *fields;
 /*
  * implproto - print prototype for function implementing a run-time operation.
  */
-novalue implproto(ip)
+void implproto(ip)
 struct implement *ip;
    {
    if (ip->iconc_flgs & ProtoPrint)
       return;    /* only print prototype once */
    fprintf(inclfile, "int %c%c%c_%s ", ip->oper_typ, ip->prefix[0],
        ip->prefix[1], ip->name);
-   fprintf(inclfile, "Params((int r_nargs, dptr r_args, dptr r_rslt, ");
-   fprintf(inclfile,"continuation r_s_cont));\n");
+   fprintf(inclfile, "(int r_nargs, dptr r_args, dptr r_rslt, ");
+   fprintf(inclfile,"continuation r_s_cont);\n");
    ip->iconc_flgs |= ProtoPrint;
    }
 
 /*
  * const_blks - output blocks for cset and real constants.
  */
-novalue const_blks()
+void const_blks()
    {
    register int i;
    register struct centry *cptr;
@@ -588,7 +587,7 @@ novalue const_blks()
 /*
  * reccnstr - output record constructors.
  */
-novalue recconstr(r)
+void recconstr(r)
 struct rentry *r;
    {
    register char *name;
@@ -643,7 +642,7 @@ struct rentry *r;
 /*
  * outerfnc - output code for the outer function implementing a procedure.
  */
-novalue outerfnc(fnc)
+void outerfnc(fnc)
 struct c_fnc *fnc;
    {
    char *prefix;
@@ -675,7 +674,7 @@ struct c_fnc *fnc;
        *  prototype.
        */
       sep = "";
-      fprintf(inclfile, "hidden int P%s_%s Params((", prefix, name);
+      fprintf(inclfile, "static int P%s_%s (", prefix, name);
       fprintf(codefile, "static int P%s_%s(", prefix, name);
       if (nparms != 0) {
          fprintf(inclfile, "dptr r_args");
@@ -693,8 +692,8 @@ struct c_fnc *fnc;
          sep = ", ";
          }
       if (*sep == '\0')
-         fprintf(inclfile, "noargs");
-      fprintf(inclfile, "));\n");
+         fprintf(inclfile, "void");
+      fprintf(inclfile, ");\n");
       fprintf(codefile, ")\n");
       if (nparms != 0)
          fprintf(codefile, "dptr r_args;\n");
@@ -726,7 +725,7 @@ struct c_fnc *fnc;
    fprintf(codefile, "\n");
    fprintf(codefile, "   r_frame.old_pfp = pfp;\n");
    fprintf(codefile, "   pfp = (struct p_frame *)&r_frame;\n");
-   fprintf(codefile, "   r_frame.old_argp = argp;\n");
+   fprintf(codefile, "   r_frame.old_argp = glbl_argp;\n");
    if (!optim || ret_flag & (DoesRet | DoesSusp))
       fprintf(codefile, "   r_frame.rslt = r_rslt;\n");
    else
@@ -756,9 +755,9 @@ struct c_fnc *fnc;
        *  site. There is not much to do here.
        */
       if (nparms == 0)
-         fprintf(codefile, "   argp = NULL;\n");
+         fprintf(codefile, "   glbl_argp = NULL;\n");
       else
-         fprintf(codefile, "   argp = r_args;\n");
+         fprintf(codefile, "   glbl_argp = r_args;\n");
       }
    else {
       /*
@@ -808,7 +807,7 @@ struct c_fnc *fnc;
             first_arg);
 #endif					/* OptimizeLoop */
          }
-      fprintf(codefile, "   argp = &r_frame.tend.d[%d];\n", first_arg);
+      fprintf(codefile, "   glbl_argp = &r_frame.tend.d[%d];\n", first_arg);
       }
    fprintf(codefile, "   r_frame.tend.num = %d;\n", ntend);
    fprintf(codefile, "   r_frame.tend.previous = tend;\n");
@@ -840,7 +839,7 @@ struct c_fnc *fnc;
 /*
  * prt_fnc - output C function that implements a continuation.
  */
-novalue prt_fnc(fnc)
+void prt_fnc(fnc)
 struct c_fnc *fnc;
    {
    struct code *sig;
@@ -857,7 +856,7 @@ struct c_fnc *fnc;
          sig = ChkBound(sig);
          if (!(sig->LabFlg & FncPrtd)) {
             ChkSeqNum(sig);
-            fprintf(inclfile, "hidden int sig_%d Params((noargs));\n",
+            fprintf(inclfile, "static int sig_%d (void);\n",
                sig->SeqNum);
    
             fprintf(codefile, "\n");
@@ -875,7 +874,7 @@ struct c_fnc *fnc;
       prefix = fnc->prefix;
       name = cur_proc->name;
    
-      fprintf(inclfile, "hidden int P%s_%s Params((noargs));\n", prefix, name);
+      fprintf(inclfile, "static int P%s_%s (void);\n", prefix, name);
    
       fprintf(codefile, "\n");
       fprintf(codefile, "static int P%s_%s()\n", prefix, name);
@@ -902,7 +901,7 @@ struct c_fnc *fnc;
 /*
  * prt_frame - output the definition for a procedure frame.
  */
-novalue prt_frame(prefix, ntend, n_itmp, n_dtmp, n_sbuf, n_cbuf)
+void prt_frame(prefix, ntend, n_itmp, n_dtmp, n_sbuf, n_cbuf)
 char *prefix;
 int ntend;
 int n_itmp;
@@ -950,7 +949,7 @@ int n_cbuf;
 /*
  * prtcode - print a list of C code.
  */
-static novalue prtcode(cd, outer)
+static void prtcode(cd, outer)
 struct code *cd;
 int outer;
    {
@@ -1106,7 +1105,7 @@ int outer;
                }
             fprintf(codefile, "   tend = r_frame.tend.previous;\n");
             fprintf(codefile, "   pfp = r_frame.old_pfp;\n");
-            fprintf(codefile, "   argp = r_frame.old_argp;\n");
+            fprintf(codefile, "   glbl_argp = r_frame.old_argp;\n");
             if (line_info) {
                fprintf(codefile, "   line_num = r_frame.debug.old_line;\n");
                fprintf(codefile, "   file_name = r_frame.debug.old_fname;\n");
@@ -1125,7 +1124,7 @@ int outer;
                }
             fprintf(codefile, "   tend = r_frame.tend.previous;\n");
             fprintf(codefile, "   pfp = r_frame.old_pfp;\n");
-            fprintf(codefile, "   argp = r_frame.old_argp;\n");
+            fprintf(codefile, "   glbl_argp = r_frame.old_argp;\n");
             if (line_info) {
                fprintf(codefile, "   line_num = r_frame.debug.old_line;\n");
                fprintf(codefile, "   file_name = r_frame.debug.old_fname;\n");
@@ -1207,7 +1206,7 @@ int outer;
 /*
  * prt_var - output C code to reference an Icon named variable.
  */
-static novalue prt_var(var, outer)
+static void prt_var(var, outer)
 struct lentry *var;
 int outer;
    {
@@ -1223,7 +1222,7 @@ int outer;
          fprintf(codefile, ".tend.d[%d]", var->val.index);
          break;
       case F_Argument:
-         fprintf(codefile, "argp[%d]", var->val.index);
+         fprintf(codefile, "glbl_argp[%d]", var->val.index);
          }
 
    /*
@@ -1235,7 +1234,7 @@ int outer;
 /*
  * prt_ary - print an array of code fragments.
  */
-static novalue prt_ary(cd, outer)
+static void prt_ary(cd, outer)
 struct code *cd;
 int outer;
    {
@@ -1298,7 +1297,7 @@ int outer;
  * frame - access to the procedure frame. Access directly from outer function,
  *   but access through r_pfp from a continuation.
  */
-static novalue frame(outer)
+static void frame(outer)
 int outer;
    {
    if (outer)
@@ -1310,7 +1309,7 @@ int outer;
 /*
  * prtpccall - print procedure continuation call.
  */
-static novalue prtpccall(outer)
+static void prtpccall(outer)
 int outer;
    {
    int first_arg;
@@ -1327,7 +1326,7 @@ int outer;
       fprintf(codefile, "   {\n");
       fprintf(codefile, "   dptr r_argp_sav;\n");
       fprintf(codefile, "\n");
-      fprintf(codefile, "   r_argp_sav = argp;\n");
+      fprintf(codefile, "   r_argp_sav = glbl_argp;\n");
       }
    if (debug_info) {
       fprintf(codefile, "   --k_level;\n");
@@ -1336,7 +1335,7 @@ int outer;
    fprintf(codefile, "   pfp = ");
    frame(outer);
    fprintf(codefile, ".old_pfp;\n");
-   fprintf(codefile, "   argp = ");
+   fprintf(codefile, "   glbl_argp = ");
    frame(outer);
    fprintf(codefile, ".old_argp;\n");
    if (line_info) {
@@ -1361,16 +1360,16 @@ int outer;
    frame(outer);
    fprintf(codefile, ";\n");
    if (cur_proc->nargs == 0)
-      fprintf(codefile, "   argp = NULL;\n");
+      fprintf(codefile, "   glbl_argp = NULL;\n");
    else {
       if (optim) {
          if (outer)
-            fprintf(codefile, "   argp = r_args;\n");
+            fprintf(codefile, "   glbl_argp = r_args;\n");
          else
-            fprintf(codefile, "   argp = r_argp_sav;\n");
+            fprintf(codefile, "   glbl_argp = r_argp_sav;\n");
          }
       else {
-         fprintf(codefile, "   argp = &");
+         fprintf(codefile, "   glbl_argp = &");
          if (outer)
             fprintf(codefile, "r_frame.");
          else
@@ -1389,7 +1388,7 @@ int outer;
 /*
  * smpl_clsg - print call and signal handling code, but nothing fancy.
  */
-static novalue smpl_clsg(call, outer)
+static void smpl_clsg(call, outer)
 struct code *call;
 int outer;
    {
@@ -1414,7 +1413,7 @@ int outer;
  * chkforgn - produce code to see if the current signal belongs to a
  *   procedure higher up the call chain and pass it along if it does.
  */
-static novalue chkforgn(outer)
+static void chkforgn(outer)
 int outer;
    {
    fprintf(codefile, "   if (pfp != (struct p_frame *)");
@@ -1431,7 +1430,7 @@ int outer;
 /*
  * good_clsg - print call and signal handling code and do a good job.
  */
-static novalue good_clsg(call, outer)
+static void good_clsg(call, outer)
 struct code *call;
 int outer;
    {
@@ -1715,7 +1714,7 @@ int outer;
 /*
  * prtcall - print call.
  */
-static novalue prtcall(call, outer)
+static void prtcall(call, outer)
 struct code *call;
 int outer;
    {
@@ -1757,7 +1756,7 @@ int outer;
 /*
  * prt_cont - print the name of a continuation.
  */
-static novalue prt_cont(cont)
+static void prt_cont(cont)
 struct c_fnc *cont;
    {
    struct code *sig;
@@ -1789,7 +1788,7 @@ struct c_fnc *cont;
  * val_loc - output code referencing a value location (usually variable of
  *  some sort).
  */
-static novalue val_loc(loc, outer)
+static void val_loc(loc, outer)
 struct val_loc *loc;
 int outer;
    {
@@ -1880,7 +1879,7 @@ int outer;
 /*
  * prt_cond - print a condition (signal number).
  */
-static novalue prt_cond(cond)
+static void prt_cond(cond)
 struct code *cond;
    {
    if (cond == &resume)
@@ -1900,7 +1899,7 @@ struct code *cond;
  * initpblk - write a procedure block along with initialization up to the
  *   the array of qualifiers.
  */
-static novalue initpblk(f, c, prefix, name, nquals, nparam, ndynam, nstatic,
+static void initpblk(f, c, prefix, name, nquals, nparam, ndynam, nstatic,
    frststat)
 FILE *f;      /* output file */
 int c;        /* distinguishes procedures, functions, record constructors */
