@@ -1,7 +1,6 @@
 /*
  * csym.c -- functions for symbol table management.
  */
-#include <ctype.h>
 #include "../h/gsupport.h"
 #include "cglobals.h"
 #include "ctrans.h"
@@ -15,23 +14,23 @@
  * Prototypes.
  */
 
-hidden struct gentry    *alcglob  Params((struct gentry *blink,
-				    char *name,int flag));
-hidden struct fentry    *alcfld   Params((struct fentry *blink, char *name,
-				    struct par_rec *rp));
-hidden struct centry    *alclit	  Params((struct centry *blink,
-				    char *image, int len,int flag));
-hidden struct lentry    *alcloc	  Params((struct lentry *blink,
-				    char *name,int flag));
-hidden struct par_rec   *alcprec  Params((struct rentry *rec, int offset,
-				    struct par_rec *next));
-hidden struct centry    *clookup  Params((char *image,int flag));
-hidden struct lentry    *dcl_loc  Params((char *id, int id_type,
-                                    struct lentry *next));
-hidden struct lentry    *llookup  Params((char *id));
-hidden novalue           opstrinv Params((struct implement *ip));
-hidden struct gentry    *putglob  Params((char *id,int id_type));
-hidden struct gentry    *try_gbl  Params((char *id));
+static struct gentry    *alcglob  (struct gentry *blink,
+				    char *name,int flag);
+static struct fentry    *alcfld   (struct fentry *blink, char *name,
+				    struct par_rec *rp);
+static struct centry    *alclit	  (struct centry *blink,
+				    char *image, int len,int flag);
+static struct lentry    *alcloc	  (struct lentry *blink,
+				    char *name,int flag);
+static struct par_rec   *alcprec  (struct rentry *rec, int offset,
+				    struct par_rec *next);
+static struct centry    *clookup  (char *image,int flag);
+static struct lentry    *dcl_loc  (char *id, int id_type,
+                                    struct lentry *next);
+static struct lentry    *llookup  (char *id);
+static void           opstrinv (struct implement *ip);
+static struct gentry    *putglob  (char *id,int id_type);
+static struct gentry    *try_gbl  (char *id);
 
 int max_sym = 0;  /* max number of parameter symbols in run-time routines */
 int max_prm = 0;  /* max number of parameters for any invocable routine */
@@ -82,7 +81,7 @@ int flag;
  *  the identifier if it isn't already there.  Some semantic checks
  *  are performed.
  */
-novalue install(name, flag)
+void install(name, flag)
 char *name;
 int flag;
    {
@@ -300,7 +299,7 @@ int flag;
 /*
  * symdump - dump symbol tables.
  */
-novalue symdump()
+void symdump()
    {
    struct pentry *proc;
 
@@ -318,7 +317,7 @@ novalue symdump()
 /*
  * prt_flgs - print flags from a symbol table entry.
  */
-static novalue prt_flgs(flags)
+static void prt_flgs(flags)
 int flags;
    {
    if (flags & F_Global)
@@ -355,7 +354,7 @@ int flags;
  * ldump displays local symbol table to stderr.
  */
 
-novalue ldump(lhash)
+void ldump(lhash)
 struct lentry **lhash;
    {
    register int i;
@@ -379,7 +378,7 @@ struct lentry **lhash;
  * gdump displays global symbol table to stderr.
  */
 
-novalue gdump()
+void gdump()
    {
    register int i;
    register struct gentry *gptr;
@@ -400,7 +399,7 @@ novalue gdump()
  * cdump displays constant symbol table to stderr.
  */
 
-novalue cdump()
+void cdump()
    {
    register int i;
    register struct centry *cptr;
@@ -420,7 +419,7 @@ novalue cdump()
 /*
  * fdump displays field symbol table to stderr.
  */
-novalue fdump()
+void fdump()
    {
    int i;
    struct par_rec *prptr;
@@ -443,7 +442,7 @@ novalue fdump()
 /*
  * prt_flds - print a list of fields stored in reverse order.
  */
-static novalue prt_flds(f)
+static void prt_flds(f)
 struct fldname *f;
    {
    if (f == NULL)
@@ -455,7 +454,7 @@ struct fldname *f;
 /*
  * rdump displays list of records and their fields.
  */
-novalue rdump()
+void rdump()
    {
    struct rentry *rp;
 
@@ -571,7 +570,7 @@ struct par_rec *next;
 /*
  * resolve - resolve the scope of undeclared identifiers.
  */
-novalue resolve(proc)
+void resolve(proc)
 struct pentry *proc;
    {
    struct lentry **lhash;
@@ -647,7 +646,7 @@ char *id;
 /*
  * invoc_grp - called when "invocable all" is encountered.
  */
-novalue invoc_grp(grp)
+void invoc_grp(grp)
 char *grp;
    {
    if (grp == spec_str("all"))
@@ -659,7 +658,7 @@ char *grp;
 /*
  * invocbl - indicate that the operator is needed for for string invocation.
  */
-novalue invocbl(op, arity)
+void invocbl(op, arity)
 nodeptr op;
 int arity;
    {
@@ -675,7 +674,7 @@ int arity;
 /*
  * chkstrinv - check to see what is needed for string invocation.
  */
-novalue chkstrinv()
+void chkstrinv()
    {
    struct strinv *si;
    struct gentry *gp;
@@ -779,7 +778,7 @@ novalue chkstrinv()
 /*
  * opstrinv - set up string invocation for an operator.
  */
-static novalue opstrinv(ip)
+static void opstrinv(ip)
 struct implement *ip;
    {
    char c1, c2;
