@@ -7,14 +7,12 @@
 #ifndef CUsage
    #define CUsage "[-C C-comp] [-E] [-T] [-c] [-f{adelns}] [-n{acest}]\n\
  [-o ofile] [-p C-opts] [-r runtime] [-s] [-t] [-u] [-v i]"
-#endif				/* CUsage */
+#endif					/* CUsage */
 
 #define Abs(n) ((n) >= 0 ? (n) : -(n))
 #define Max(x,y) ((x)>(y)?(x):(y))
 
-#if !EBCDIC
 #define tonum(c)	(isdigit(c) ? (c - '0') : ((c & 037) + 9))
-#endif					/* !EBCDIC */
 
 /*
  * Hash tables must be a power of 2.
