@@ -13,9 +13,9 @@
 /*
  * prototypes for static functions.
  */
-hidden nodeptr chk_empty Params((nodeptr n));
-hidden novalue put_elms  Params((nodeptr t, nodeptr args, int slot));
-hidden nodeptr subsc_nd  Params((nodeptr op, nodeptr arg1, nodeptr arg2));
+static nodeptr chk_empty (nodeptr n);
+static void put_elms  (nodeptr t, nodeptr args, int slot);
+static nodeptr subsc_nd  (nodeptr op, nodeptr arg1, nodeptr arg2);
 
 /*
  *  tree[1-6] construct parse tree nodes with specified values.
@@ -335,7 +335,7 @@ nodeptr args;
  * put_elms - convert a linked list of arguments into an array of arguments
  *  in a node.
  */
-static novalue put_elms(t, args, slot)
+static void put_elms(t, args, slot)
 nodeptr t;
 nodeptr args;
 int slot;
@@ -463,7 +463,7 @@ nodeptr oprnd;
          return unary_nd(nd,multiunary(++op,loc_model,oprnd));
          }
    fprintf(stderr, "compiler error: inconsistent parsing of unary operators");
-   exit(ErrorExit);
+   exit(EXIT_FAILURE);
    }
 
 /*
