@@ -16,16 +16,16 @@ struct op_symentry *cur_symtab; /* symbol table for current operation */
 /*
  * Prototypes for static functions.
  */
-hidden struct code *and_cond Params((struct code *cd1, struct code *cd2));
-hidden int          cnv_anlz Params((unsigned int typcd, struct il_code *src,
+static struct code *and_cond (struct code *cd1, struct code *cd2);
+static int          cnv_anlz (unsigned int typcd, struct il_code *src,
                                struct il_c *dflt, struct il_c *dest,
-                               struct code **cdp));
-hidden int          defer_il Params((struct il_code *il));
-hidden int          if_anlz  Params((struct il_code *il));
-hidden novalue      ilc_anlz Params((struct il_c *ilc));
-hidden int          il_anlz  Params((struct il_code *il));
-hidden novalue      ret_anlz Params((struct il_c *ilc));
-hidden int          tc_anlz  Params((struct il_code *il, int has_dflt));
+                               struct code **cdp);
+static int          defer_il (struct il_code *il);
+static int          if_anlz  (struct il_code *il);
+static void      ilc_anlz (struct il_c *ilc);
+static int          il_anlz  (struct il_code *il);
+static void      ret_anlz (struct il_c *ilc);
+static int          tc_anlz  (struct il_code *il, int has_dflt);
 
 static int n_branches;  /* number branches caused by run-time type checking */
 static int side_effect; /* abstract clause indicates side-effect */
@@ -272,7 +272,7 @@ struct il_code *il;
 
       default:
          fprintf(stderr, "compiler error: unknown info in data base\n");
-         exit(ErrorExit);
+         exit(EXIT_FAILURE);
          /* NOTREACHED */
       }
    }
@@ -386,7 +386,7 @@ struct code **cdp;
 
       default:
          fprintf(stderr, "compiler error: unknown info in data base\n");
-         exit(ErrorExit);
+         exit(EXIT_FAILURE);
          /* NOTREACHED */
       }
    }
@@ -573,7 +573,7 @@ struct code **cdp;
 /*
  * ilc_anlz - gather information about in-line C code.
  */
-static novalue ilc_anlz(ilc)
+static void ilc_anlz(ilc)
 struct il_c *ilc;
    {
    while (ilc != NULL) {
@@ -627,7 +627,7 @@ struct il_c *ilc;
  * ret_anlz - gather information about the in-line C code associated
  *   with a return or suspend.
  */
-static novalue ret_anlz(ilc)
+static void ret_anlz(ilc)
 struct il_c *ilc;
    {
    int i;
@@ -669,7 +669,7 @@ struct il_code *il;
  *   that can be used (if there are more than two, the code is not
  *   in-lined).
  */
-novalue findcases(il, has_dflt, case_anlz)
+void findcases(il, has_dflt, case_anlz)
 struct il_code *il;
 int has_dflt;
 struct case_anlz *case_anlz;
@@ -743,7 +743,7 @@ int has_dflt;
 /*
  * arth_anlz - analyze the type checking of an arith_case statement.
  */
-novalue arth_anlz(var1, var2, maybe_int, maybe_dbl, chk1, conv1p, chk2, conv2p)
+void arth_anlz(var1, var2, maybe_int, maybe_dbl, chk1, conv1p, chk2, conv2p)
 struct il_code *var1;
 struct il_code *var2;
 int *maybe_int;
