@@ -9,18 +9,8 @@
 
 int nlflag = 0;		/* newline last seen */
 
-#if MACINTOSH
-   #if MPW
-      #include <CursorCtl.h>
-      #define CURSORINTERVAL 100
-   #endif				/* MPW */
-#endif					/* MACINTOSH */
-
-#if !EBCDIC
-   #define tonum(c)	(isdigit(c) ? (c - '0') : ((c & 037) + 9))
-#endif					/* !EBCDIC */
+#define tonum(c)	(isdigit(c) ? (c - '0') : ((c & 037) + 9))
 
-#if !EBCDIC
 /*
  * getopc - get an opcode from infile, return the opcode number (via
  *  binary search of opcode table), and point id at the name of the opcode.
@@ -55,35 +45,6 @@ char **id;
    *id = s;
    return 0;
    }
-#else					/* !EBCDIC */
-/*
- * getopc - get an opcode from infile, return the opcode number (via
- * sequential search of opcode table) and point id at the name of the opcode.
- */
- 
-int getopc(id)
-char **id;
-   {
-   register char *s;
-   register struct opentry *p;
-   register int test;
-   word indx;
- 
-   indx = getstr();
-   if (indx == -1)
-      return EOF;
-   s = &lsspace[indx];
-   for(test=0;test < NOPCODES; test++) {
-       p = &optable[test];
-       if( strcmp(p->op_name, s) == 0) {
-           *id = p->op_name;
-           return (p->op_code);
-       }
-   }
-   *id = s;
-   return 0;
-   }
-#endif					/* !EBCDIC */
 
 /*
  * getid - get an identifier from infile, put it in the identifier
@@ -107,33 +68,11 @@ word getstr()
    register int c;
    register word indx;
 
-#if MACINTOSH
-   #if MPW
-      {
-      static short cursorcount = CURSORINTERVAL;
-      if (--cursorcount == 0) {
-         RotateCursor(-32);
-         cursorcount = CURSORINTERVAL;
-         }
-      }
-   #endif					/* MPW */
-#endif					/* MACINTOSH */
-
    indx = lsfree;
    while ((c = getc(infile)) == ' ' || c == '\t') ;
    if (c == EOF)
       return -1;
-
-#if MSDOS && INTEL_386
-   /*
-    * Code Builder lets carriage returns through sometimes.
-    */
-   while (c != ' ' && c != '\t' && c != '\n' && c != '\r' && c != ',' &&
-      c != EOF) {
-#else					/* MSDOS && INTEL_386 */
    while (c != ' ' && c != '\t' && c != '\n' && c != ',' && c != EOF) {
-#endif					/* MSDOS && INTEL_386 */
-
       if (indx >= stsize)
          lsspace = (char *)trealloc(lsspace, NULL, &stsize, 1, 1,
             "string space");
@@ -158,16 +97,7 @@ word getrest()
    register word indx;
 
    indx = lsfree;
-
-#if MSDOS && INTEL_386
-   /*
-    * Code Builder lets carriage returns through on occasion
-    */
-   while ((c = getc(infile)) != '\n' && c != '\r' && c != EOF) {
-#else					/* MSDOS && INTEL_386 */
    while ((c = getc(infile)) != '\n' && c != EOF) {
-#endif					/* MSDOS && INTEL_386 */
-
       if (indx >= stsize)
          lsspace = (char *)trealloc(lsspace, NULL, &stsize, 1, 1,
             "string space");
@@ -244,7 +174,7 @@ long getint(j,wp)
    if (lsfree + j >= stsize)
       lsspace = (char *)trealloc(lsspace, NULL, &stsize, 1, j, "string space");
    indx = lsfree;
-   
+
    while ((c = getc(infile)) >= '0' && c <= '9') {
       lsspace[indx++] = c;
       result = result * 10 + (c - '0');
