@@ -21,6 +21,8 @@ static void	emitl		(char *s,int a);
 static void	emitlab		(int l);
 static void	emitn		(char *s,int a);
 static void	emits		(char *s,char *a);
+static void	emitfile	(nodeptr n);
+static void	emitline	(nodeptr n);
 static void	setloc		(nodeptr n);
 static int	traverse	(nodeptr t);
 static void	unopa		(int op, nodeptr t);
@@ -116,11 +118,9 @@ register nodeptr t;
 	 loopsp->markcount++;
 	 traverse(Tree0(t));		/* evaluate first alternative */
 	 loopsp->markcount--;
-
-#ifdef EventMon
-         setloc(t);
-#endif					/* EventMon */
-
+         #ifdef EventMon
+            setloc(t);
+         #endif				/* EventMon */
 	 emit("esusp");                 /*  and suspend with its result */
 	 emitl("goto", lab+1);
 	 emitlab(lab);
@@ -279,7 +279,6 @@ register nodeptr t;
 	 free(Tree1(t));
 	 break;
 
-
       case N_Id:			/* identifier */
 	 emitn("var", (int)Val0(t));
 	 break;
@@ -312,7 +311,6 @@ register nodeptr t;
 	 emitn("int", (int)Val0(t));
 	 break;
 
-
       case N_Apply:			/* application */
          traverse(Tree0(t));
          traverse(Tree1(t));
@@ -522,13 +520,13 @@ register nodeptr t;
 	 casesp = casestk;
 	 creatsp = creatstk;
 
-
 	 writecheck(fprintf(codefile, "proc %s\n", Str0(Tree0(t))));
+	 emitfile(t);
 	 lout(codefile);
 	 constout(codefile);
-
 	 emit("declend");
-	 setloc(t);
+	 emitline(t);
+
 	 if (TType(Tree1(t)) != N_Empty) {
 	    lab = alclab(1);
 	    emitl("init", lab);
@@ -990,16 +988,24 @@ int op;
    }
 
 /*
- * setloc emits "filen" and "line" directives for the source location of
- *  node n.  A directive is only emitted if the corresponding value
- *  has changed since the last time setloc was called.  Note:  File(n)
- *  reportedly occasionally points at uninitialized data, producing
- *  bogus results (as well as reams of filen commands).
+ * emitfile(n) emits "filen" directives for node n's source location.
+ * emitline(n) emits "line" and possibly "colm" directives.
+ * setloc(n) does both.
+ *  A directive is only emitted if the corresponding value
+ *  has changed since the previous call.
+ *
  */
 static char *lastfiln = NULL;
 static int lastlin = 0;
 
 static void setloc(n)
+nodeptr n;
+   {
+   emitfile(n);
+   emitline(n);
+   }
+
+static void emitfile(n)
 nodeptr n;
    {
    if ((n != NULL) &&
@@ -1009,43 +1015,30 @@ nodeptr n;
          lastfiln = File(n);
          emits("filen", lastfiln);
          }
-
-#ifdef SrcColumnInfo
-   /*
-    * if either line or column has changed, emit location information
-    */
-   if (((Col(n) << 16) + Line(n)) != lastlin) {
-      lastlin = (Col(n) << 16) + Line(n);
-      emitn("line",Line(n));
-      emitn("colm",Col(n));
-      }
-#else					/* SrcColumnInfo */
-   /*
-    * if line has changed, emit line information
-    */
-   if (Line(n) != lastlin) {
-      lastlin = Line(n);
-      emitn("line", lastlin);
-      }
-#endif					/* SrcColumnInfo */
-
-
    }
 
-#ifdef MultipleRuns
-/*
- * Reinitialize last file name and line number for repeated runs.
- */
-void tcodeinit()
+static void emitline(n)
+nodeptr n;
    {
-   lastfiln = NULL;
-
-   #ifdef EventMon
-      lastcol = 0;
-   #endif				/* EventMon */
-
+   #ifdef SrcColumnInfo
+      /*
+       * if either line or column has changed, emit location information
+       */
+      if (((Col(n) << 16) + Line(n)) != lastlin) {
+         lastlin = (Col(n) << 16) + Line(n);
+         emitn("line",Line(n));
+         emitn("colm",Col(n));
+         }
+   #else				/* SrcColumnInfo */
+      /*
+       * if line has changed, emit line information
+       */
+      if (Line(n) != lastlin) {
+         lastlin = Line(n);
+         emitn("line", lastlin);
+         }
+   #endif				/* SrcColumnInfo */
    }
-#endif					/* Multiple Runs */
 
 /*
  * The emit* routines output ucode to codefile.  The various routines are:
@@ -1082,7 +1075,6 @@ int a;
    writecheck(fprintf(codefile, "\t%s\t%d\n", s, a));
    }
 
-
 static void emits(s, a)
 char *s, *a;
    {
