@@ -3,8 +3,8 @@
  */
 
 #ifndef Global
-#define Global extern
-#define Init(v)
+   #define Global extern
+   #define Init(v)
 #endif					/* Global */
 
 /*
@@ -12,7 +12,7 @@
  */
 Global int cmask;			/* mask for constant table hash */
 Global int fmask;			/* mask for field table hash */
-Global int gmask;			/* mask for global table hash */	
+Global int gmask;			/* mask for global table hash */
 Global int imask;			/* mask for identifier table hash */
 Global int lmask;			/* mask for local table hash */
 
@@ -40,37 +40,16 @@ Global unsigned int lhsize	Init(128);	/* local hash table */
  * Variables related to command processing.
  */
 Global char *progname	Init("icont");	/* program name for diagnostics */
-
-#if ATARI_ST
-Global char *patharg	Init(0);	/* -p: path for finding iconx */
-#endif					/* ATARI_ST */
-
-#if MSDOS
-#if ZTC_386
-Global int makeExe	Init(0);	/* -I: create .icx instead of .exe */
-#else					/* ZTC_386 */
-Global int makeExe	Init(1);	/* -X: create .exe instead of .icx */
-#endif					/* ZTC_386 */
-Global long fileOffsetOfStuffThatGoesInICX
-			Init(0);	/* remains 0 -f -X is not used */
-#endif					/* MSDOS */
-
-					/* set in link.c; used in lcode.c */
 Global int silent	Init(0);	/* -s: suppress info messages? */
-Global int m4pre	Init(0);	/* -m: use m4 preprocessor? [UNIX] */
+Global int m4pre	Init(0);	/* -m: use m4 preprocessor? */
 Global int uwarn	Init(0);	/* -u: warn about undefined ids? */
 Global int trace	Init(0);	/* -t: initial &trace value */
 Global int pponly	Init(0);	/* -E: preprocess only */
 Global int strinv	Init(0);	/* -f s: allow full string invocation */
 Global int verbose	Init(1);	/* -v n: verbosity of commentary */
 
-
-#if OS2
-Global int noexe	Init(0);	/* -i: stop with .ICX file */
-#endif
-
 #ifdef DeBugLinker
-Global int Dflag	Init(0);	/* -L: linker debug (write .ux file) */
+   Global int Dflag	Init(0);	/* -L: linker debug (write .ux file) */
 #endif					/* DeBugLinker */
 
 /*
