@@ -155,7 +155,7 @@ YYSTYPE yylval, yyval;
  * xfree(p) -- used with free(p) macro to avoid compiler errors from
  *  miscast free calls generated by Yacc.
  */
-static novalue xfree(p)
+static void xfree(p)
 char *p;
 {
    free(p);
@@ -1411,7 +1411,7 @@ yyparse()
 	*/
 	switch( yytmp )
 	{
-		
+
 case 1:
 # line 179 "tgram.g"
 {gout(globfile);} break;
