@@ -14,7 +14,7 @@
  * Prototypes.
  */
 
-static	void	trans1		(char *filename);
+static	void	trans1		(char *filename, char *tgtdir);
 
 int tfatals;			/* number of fatal errors in file */
 int afatals;			/* total number of fatal errors */
@@ -26,20 +26,15 @@ int peekc;			/* one-character look ahead */
 /*
  * translate a number of files, returning an error count
  */
-int trans(ifiles)
+int trans(ifiles, tgtdir)
 char **ifiles;
+char *tgtdir;
    {
-   tmalloc();			/* allocate memory for translation */
-
    afatals = 0;
 
-#ifdef MultipleRuns
-   yylexinit();			/* initialize lexical analyser */
-   tcodeinit();			/* initialize code generator */
-#endif					/* Multiple Runs */
-
+   tmalloc();			/* allocate memory for translation */
    while (*ifiles) {
-      trans1(*ifiles++);	/* translate each file in turn */
+      trans1(*ifiles++, tgtdir);	/* translate each file in turn */
       afatals += tfatals;
       }
    tmfree();			/* free memory used for translation */
@@ -63,11 +58,11 @@ char **ifiles;
 /*
  * translate one file.
  */
-static void trans1(filename)
-char *filename;
+static void trans1(filename, tgtdir)
+char *filename, *tgtdir;
 {
-   char oname1[MaxFileName];	/* buffer for constructing file name */
-   char oname2[MaxFileName];	/* buffer for constructing file name */
+   char oname1[MaxPath];	/* buffer for constructing file name */
+   char oname2[MaxPath];	/* buffer for constructing file name */
 
    tfatals = 0;			/* reset error counts */
    nocode = 0;			/* allow code generation */
@@ -88,47 +83,19 @@ char *filename;
       return;
       }
 
-#ifndef VarTran
    /*
     * Form names for the .u1 and .u2 files and open them.
     *  Write the ucode version number to the .u2 file.
     */
-
-   makename(oname1, TargetDir, filename, U1Suffix);
-
-#if MVS || VM
-/*
- * Even though the ucode data is all reasonable text characters, use
- *  of text I/O may cause problems if a line is larger than LRECL.
- *  This is likely to be true with any compiler, though the precise
- *  disaster which results may vary.
- *
- * On CMS (and sometimes on MVS), empty files are not readable later.
- *  Since the .U1 file may be empty, we start it off with an extra
- *  blank (thrown away on input) to make sure there's something there.
- */
-   codefile = fopen(oname1, WriteBinary);   /* avoid line splits */
-   if (codefile != NULL)
-      putc(' ', codefile);
-#else					/* MVS || VM */
-   codefile = fopen(oname1, WriteText);
-#endif					/* MVS || VM */
-
+   makename(oname1, tgtdir, filename, U1Suffix);
+   codefile = fopen(oname1, "w");
    if (codefile == NULL)
       quitf("cannot create %s", oname1);
-
-   makename(oname2, TargetDir, filename, U2Suffix);
-
-#if MVS || VM
-   globfile = fopen(oname2, WriteBinary);
-#else					/* MVS || VM */
-   globfile = fopen(oname2, WriteText);
-#endif					/* MVS || VM */
-
+   makename(oname2, tgtdir, filename, U2Suffix);
+   globfile = fopen(oname2, "w");
    if (globfile == NULL)
       quitf("cannot create %s", oname2);
    writecheck(fprintf(globfile,"version\t%s\n",UVersion));
-#endif					/* VarTran */
 
    tok_loc.n_file = filename;
    in_line = 1;
@@ -139,12 +106,8 @@ char *filename;
    /*
     * Close the output files.
     */
-
-#ifndef VarTran
    if (fclose(codefile) != 0 || fclose(globfile) != 0)
       quit("cannot close ucode file");
-#endif					/* VarTran */
-
    if (tfatals) {
       remove(oname1);
       remove(oname2);
