@@ -4,17 +4,15 @@
  */
 #include "../preproc/preproc.h"
 #include "../preproc/ptoken.h"
-#include <ctype.h>
 
 /*
  * Prototypes for static functions.
  */
-hidden int           pp_tok_id  Params((char *s));
-hidden struct token *chck_wh_sp Params((struct char_src *cs));
-hidden struct token *pp_number  Params((noargs));
-hidden struct token *char_str   Params((int delim, int tok_id));
-hidden struct token *hdr_tok    Params((int delim, int tok_id,
-                                  struct char_src *cs));
+static int           pp_tok_id  (char *s);
+static struct token *chck_wh_sp (struct char_src *cs);
+static struct token *pp_number  (void);
+static struct token *char_str   (int delim, int tok_id);
+static struct token *hdr_tok    (int delim, int tok_id, struct char_src *cs);
 
 int whsp_image = NoSpelling;    /* indicate what is in white space tokens */
 struct token *zero_tok;         /* token for literal 0 */
@@ -63,7 +61,7 @@ static struct rsrvd_wrd pp_rsrvd[] = {
 /*
  * init_tok - initialize tokenizer.
  */
-novalue init_tok()
+void init_tok()
    {
    struct rsrvd_wrd *rw;
    static int first_time = 1;
@@ -463,7 +461,7 @@ struct token *tokenize()
       AppChar(tknize_sbuf, c);
       return pp_number();
       }
-  
+
    /*
     * Check for character constant.
     */
@@ -508,7 +506,7 @@ struct token *tokenize()
             }
          else
             return new_token('.', str_install(&tknize_sbuf), fname, line);
- 
+
       case '+':
          c = *next_char;
          if (c == '+') {
@@ -529,7 +527,7 @@ struct token *tokenize()
             }
          else
             return new_token('+', str_install(&tknize_sbuf), fname, line);
- 
+
       case '-':
          c = *next_char;
          if (c == '>') {
@@ -559,7 +557,7 @@ struct token *tokenize()
             }
          else
             return new_token('-', str_install(&tknize_sbuf), fname, line);
- 
+
       case '<':
          c = *next_char;
          if (c == '<') {
@@ -590,7 +588,7 @@ struct token *tokenize()
             }
          else
             return new_token('<', str_install(&tknize_sbuf), fname, line);
- 
+
       case '>':
          c = *next_char;
          if (c == '>') {
@@ -621,7 +619,7 @@ struct token *tokenize()
             }
          else
             return new_token('>', str_install(&tknize_sbuf), fname, line);
- 
+
       case '=':
          if (*next_char == '=') {
             /*
@@ -629,11 +627,11 @@ struct token *tokenize()
              */
             AppChar(tknize_sbuf, '=');
             AdvChar();
-            return new_token(Equal, str_install(&tknize_sbuf), fname, line);
+            return new_token(TokEqual, str_install(&tknize_sbuf), fname, line);
             }
          else
             return new_token('=', str_install(&tknize_sbuf), fname, line);
- 
+
       case '!':
          if (*next_char == '=') {
             /*
@@ -645,7 +643,7 @@ struct token *tokenize()
             }
          else
             return new_token('!', str_install(&tknize_sbuf), fname, line);
- 
+
       case '&':
          c = *next_char;
          if (c == '&') {
@@ -666,7 +664,7 @@ struct token *tokenize()
             }
          else
             return new_token('&', str_install(&tknize_sbuf), fname, line);
- 
+
       case '|':
          c = *next_char;
          if (c == '|') {
@@ -687,7 +685,7 @@ struct token *tokenize()
             }
          else
             return new_token('|', str_install(&tknize_sbuf), fname, line);
- 
+
       case '*':
          if (*next_char == '=') {
             /*
@@ -711,7 +709,7 @@ struct token *tokenize()
             }
          else
             return new_token('/', str_install(&tknize_sbuf), fname, line);
- 
+
       case '%':
          if (*next_char == '=') {
             /*
@@ -723,7 +721,7 @@ struct token *tokenize()
             }
          else
             return new_token('%', str_install(&tknize_sbuf), fname, line);
- 
+
       case '^':
          if (*next_char == '=') {
             /*
@@ -735,7 +733,7 @@ struct token *tokenize()
             }
          else
             return new_token('^', str_install(&tknize_sbuf), fname, line);
- 
+
       case '#':
          /*
           * Token pasting or stringizing operator.
