@@ -5,22 +5,21 @@
 #include "../preproc/preproc.h"
 #include "../preproc/ptoken.h"
 #include "../preproc/pproto.h"
-#include <ctype.h>
 
 /*
  * Prototypes for static functions.
  */
-hidden novalue start_select Params((struct token *t));
-hidden novalue end_select   Params((struct token *t));
-hidden novalue incl_file    Params((struct token *t));
-hidden novalue define       Params((struct token *t));
-hidden int     expand       Params((struct token *t, struct macro *m));
-hidden novalue toks_to_str  Params((struct str_buf *sbuf, struct token *t));
+static void start_select (struct token *t);
+static void end_select   (struct token *t);
+static void incl_file    (struct token *t);
+static void define       (struct token *t);
+static int     expand       (struct token *t, struct macro *m);
+static void toks_to_str  (struct str_buf *sbuf, struct token *t);
 
 /*
  * start_select - handle #if, #ifdef, #ifndef
  */
-static novalue start_select(t)
+static void start_select(t)
 struct token *t;
    {
    struct token *t1;
@@ -50,7 +49,7 @@ struct token *t;
          errt2(t1, "expecting end of line following argument to #", t->image);
       free_t(t1);
       }
- 
+
    /*
     * look for the branch of the conditional inclusion to take or #endif.
     */
@@ -70,7 +69,7 @@ struct token *t;
              */
             ++nesting;
             break;
- 
+
          case PpEndif:
             /*
              * #endif found. See if this is this the end of a nested
@@ -91,7 +90,7 @@ struct token *t;
                return;
                }
             break;
-  
+
          case PpElif:
             /*
              * #elif found. If this is not a nested conditional, see if
@@ -104,7 +103,7 @@ struct token *t;
                condition = eval(t);
                }
             break;
- 
+
          case PpElse:
             /*
              * #else found. If this is not a nested conditional, take
@@ -134,7 +133,7 @@ struct token *t;
 /*
  * end_select - handle #elif, #else, and #endif
  */
-static novalue end_select(t)
+static void end_select(t)
 struct token *t;
    {
    struct tok_lst *tlst;
@@ -191,7 +190,7 @@ struct token *t;
 /*
  * incl_file - handle #include
  */
-static novalue incl_file(t)
+static void incl_file(t)
 struct token *t;
    {
    struct token *file_tok, *t1;
@@ -290,7 +289,7 @@ struct token *t;
 /*
  * define - handle #define and #begdef
  */
-static novalue define(t)
+static void define(t)
 struct token *t;
    {
    struct token *mname;   /* name of macro */
@@ -310,7 +309,7 @@ struct token *t;
    nxt_non_wh(&mname);
    if (mname->tok_id != Identifier)
       errt2(mname, "syntax error in #", t->image);
-   
+
    /*
     * Determine if this macro takes arguments.
     */
@@ -469,10 +468,8 @@ struct macro *m;
           * Allocate an array for both raw and macro-expanded token lists
           *  for the arguments.
           */
-         args = (struct tok_lst **)alloc((unsigned int)(sizeof(struct tok_lst *)
-             * nparm));
-         exp_args = (struct tok_lst **)alloc((unsigned int)(
-             sizeof(struct tok_lst *) * nparm));
+         args = alloc(nparm * sizeof(struct tok_lst *));
+         exp_args = alloc(nparm * sizeof(struct tok_lst *));
 
          /*
           * Gather the tokens for each argument.
@@ -588,7 +585,7 @@ struct macro *m;
  * toks_to_str - put in a buffer the string image of tokens up to the end of
  *    of a preprocessor directive.
  */
-static novalue toks_to_str(sbuf, t)
+static void toks_to_str(sbuf, t)
 struct str_buf *sbuf;
 struct token *t;
    {
@@ -644,7 +641,7 @@ struct token *interp_dir()
          case PpIfndef:      /* #endif */
             start_select(t);
             break;
-            
+
          case PpElif:        /* #elif */
          case PpElse:        /* #else */
          case PpEndif:       /* #endif */
@@ -683,7 +680,7 @@ struct token *interp_dir()
          case PpLine:        /* #line */
             /* this directive is handled in next_tok() */
             break;
- 
+
          case PpError:       /* #error */
             /*
              * Create an error message out of the rest of the tokens
@@ -753,82 +750,82 @@ struct token *interp_dir()
       }
    }
 
-
 /*
- * See if compiler used to build the preprocessor recognizes '\a' 
+ * See if compiler used to build the preprocessor recognizes '\a'
  *  as the bell character.
  */
+
 #if '\a' == Bell
 
-#define TokSrc interp_dir
+   #define TokSrc interp_dir
 
-#else      /*  '\a' == Bell  */
+#else					/* '\a' == Bell */
 
-#define TokSrc check_bell
+   #define TokSrc check_bell
 
-/*
- * fix_bell - replace \a characters which correct octal escape sequences.
- */
-static char *fix_bell(s)
-register char *s;
-   {
-   struct str_buf *sbuf;
-
-   sbuf = get_sbuf();
-   while (*s != '\0') {
-      AppChar(*sbuf, *s);
-      if (*s == '\\') {
-         ++s;
-         if (*s == 'a') {
-            AppChar(*sbuf, '0' + ((Bell >> 6) & 7));
-            AppChar(*sbuf, '0' + ((Bell >> 3) & 7));
-            AppChar(*sbuf, '0' + (Bell & 7));
-            }
-         else
-            AppChar(*sbuf, *s);
-         }
-      ++s;
-      }
-   s = str_install(sbuf);
-   rel_sbuf(sbuf);
-   return s;
-   }
-
-/*
- * check_bell - check for \a in character and string constants. This is only
- *  used with compilers which don't give the standard interpretation to \a.
- */
-static struct token *check_bell()
-   {
-   struct token *t;
+   /*
+    * fix_bell - replace \a characters which correct octal escape sequences.
+    */
+   static char *fix_bell(s)
    register char *s;
+      {
+      struct str_buf *sbuf;
 
-   t = interp_dir();
-   if (t == NULL)
-      return NULL;
-   switch (t->tok_id) {
-      case StrLit:
-      case LStrLit:
-      case CharConst:
-      case LCharConst:
-         s = t->image;
-         while (*s != '\0') {
-           if (*s == '\\') {
-              if (*++s == 'a') {
-                 /*
-                  * There is at least one \a to replace.
-                  */
-                 t->image = fix_bell(t->image);
-                 break;
-                 }
-              }
-           ++s;
-           }
+      sbuf = get_sbuf();
+      while (*s != '\0') {
+         AppChar(*sbuf, *s);
+         if (*s == '\\') {
+            ++s;
+            if (*s == 'a') {
+               AppChar(*sbuf, '0' + ((Bell >> 6) & 7));
+               AppChar(*sbuf, '0' + ((Bell >> 3) & 7));
+               AppChar(*sbuf, '0' + (Bell & 7));
+               }
+            else
+               AppChar(*sbuf, *s);
+            }
+         ++s;
+         }
+      s = str_install(sbuf);
+      rel_sbuf(sbuf);
+      return s;
       }
-   return t;
-   }
 
-#endif     /*  '\a' == Bell  */
+   /*
+    * check_bell - check for \a in character and string constants. This is only
+    *  used with compilers which don't give the standard interpretation to \a.
+    */
+   static struct token *check_bell()
+      {
+      struct token *t;
+      register char *s;
+
+      t = interp_dir();
+      if (t == NULL)
+         return NULL;
+      switch (t->tok_id) {
+         case StrLit:
+         case LStrLit:
+         case CharConst:
+         case LCharConst:
+            s = t->image;
+            while (*s != '\0') {
+              if (*s == '\\') {
+                 if (*++s == 'a') {
+                    /*
+                     * There is at least one \a to replace.
+                     */
+                    t->image = fix_bell(t->image);
+                    break;
+                    }
+                 }
+              ++s;
+              }
+         }
+      return t;
+      }
+
+#endif					/* '\a' == Bell */
 
 /*
  * preproc - return the next fully preprocessed token.
@@ -931,7 +928,7 @@ struct token *preproc()
                       */
                      escape_seq = s;
                      i = 1;
-                     while (i <= 3 && *s >= '0' && *s <= '7') { 
+                     while (i <= 3 && *s >= '0' && *s <= '7') {
                         ++i;
                         ++s;
                         }
