@@ -5,7 +5,7 @@
 #include "rtt.h"
 
 /*
- * prototypes for static functions. 
+ * prototypes for static functions.
  */
 static struct il_code *abstrcomp (struct node *n, int indx_stor,
                                     int chng_stor, int escapes);
@@ -50,10 +50,6 @@ int rslt_loc;		/* flag: function passed addr of result descriptor */
 
 char prfx3;		/* 3rd prefix char; used for unique body func names */
 
-#if MVS
-extern char *src_file_nm;
-#endif                                  /* MVS */
-
 /*
  * in_line - place in the data base in-line code for an operation and
  *   produce C functions for body statements.
@@ -80,13 +76,12 @@ struct node *n;
    if (ntend == 0)
       cur_impl->tnds = NULL;
    else
-      cur_impl->tnds = (struct tend_var *)alloc((unsigned int)
-         (sizeof(struct tend_var) * ntend));
+      cur_impl->tnds = alloc(ntend * sizeof(struct tend_var));
    cur_impl->ntnds = ntend;
    i = 0;
 
    /*
-    * Go back through the declarations and fill in the array for the 
+    * Go back through the declarations and fill in the array for the
     *  tended part of the data base symbol table. Array entries contain
     *  an indication of the type of tended declaration, the C code to
     *  initialize the variable if there is any, and, for block pointer
@@ -117,8 +112,7 @@ struct node *n;
    nvars += il_indx;  /* compute number of entries in this part of table */
    cur_impl->nvars = nvars;
    if (nvars > 0) {
-      cur_impl->vars = (struct ord_var *)alloc((unsigned int)
-         (sizeof(struct ord_var) * nvars));
+      cur_impl->vars = alloc(nvars * sizeof(struct ord_var));
       i = 0;
       for (sym = decl_lst; sym != NULL; sym = sym->u.declare_var.next) {
          cur_impl->vars[i].name = sym->image;
@@ -514,7 +508,7 @@ struct node *n;
                   for (n2 = sel->u[0].child; n2 != NULL; n2 = n2->u[0].child)
                      n_typ++;
                   il->u[n_fld++].n = n_typ;
-                  typ_vect = (int *)alloc((unsigned int)(sizeof(int) * n_typ));
+                  typ_vect = alloc(n_typ * sizeof(int));
                   il->u[n_fld++].vect = typ_vect;
                   n_typ = 0;
                   for (n2 = sel->u[0].child; n2 != NULL; n2 = n2->u[0].child)
@@ -750,14 +744,14 @@ int escapes;
                 */
                il = new_il(IL_VarTyp, 1);
                il->u[0].fld = il_var(n->u[0].child);
-               break; 
+               break;
             case Store:
                /*
                 * store[ <type> ]
                 */
                il = new_il(IL_Store, 1);
                il->u[0].fld = abstrcomp(n->u[0].child, 1, 0, 0);
-               break; 
+               break;
             }
          break;
       case PstfxNd:
@@ -774,10 +768,10 @@ int escapes;
                   errt3(t, typecompnt[cmpntcd].id,
                     " component is an internal reference type.\n",
                     "\t\tuse store[<type>.<component>] to \"dereference\" it");
-               break; 
+               break;
             case All_fields:
                il->u[1].n = CM_Fields;
-               break; 
+               break;
             }
          break;
       case IcnTypNd:
@@ -848,7 +842,7 @@ int escapes;
                 * Create the "new" construct for the data base with its type
                 *  code and arguments.
                 */
-               il = new_il(IL_New, 2 + nargs); 
+               il = new_il(IL_New, 2 + nargs);
                il->u[0].n = typcd;
                il->u[1].n = nargs;
                while (nargs > 1) {
@@ -909,7 +903,7 @@ int chng_stor;
 
 /*
  * body_anlz - walk the syntax tree for the C code in a body statment,
- *  analyzing the code to determine the interface needed by the C function 
+ *  analyzing the code to determine the interface needed by the C function
  *  which will implement it. Also determine how many buffers are needed.
  *  The value returned indicates whether it is possible for execution
  *  to fall through the the code.
@@ -930,7 +924,7 @@ int all;          /* input flag: need all information about operation */
    static int may_brnchto;
 
    if (n == NULL)
-      return 1; 
+      return 1;
 
    t =  n->tok;
 
@@ -1312,7 +1306,7 @@ struct node *n;
    struct sym_entry *sym;
 
    if (n == NULL)
-      return; 
+      return;
 
    /*
     * Walk the syntax tree until a block with declarations is found.
@@ -1406,12 +1400,7 @@ struct node *n;
    char buf1[6];
 
    char *cname;
-
-#if MVS
-   char buf1[MaxFileName];
-#else
-   char buf[MaxFileName];
-#endif					/* MVS */
+   char buf[MaxPath];
 
    /*
     * Figure out the next character to use as the 3rd prefix for the
@@ -1464,27 +1453,13 @@ struct node *n;
     * Use the letter indicating operation type along with body function
     *  prefixes to construct the name of the file to hold the C code.
     */
-
-#if MVS
-   {
-      struct fileparts *fp;
-      fp = fparse(src_file_nm);
-      if (*fp->member == '\0')
-         sprintf(buf1, "%c#%c%c%c", lc_letter, prfx1, prfx2, prfx3);
-      else
-         sprintf(buf1, "%s%s.ro.c(%c#%c%c%c)", fp->dir, fp->name,
-                 lc_letter, prfx1, prfx2, prfx3);
-      }
-#else                                   /* MVS */
    sprintf(buf1, "%c_%c%c%c", lc_letter, prfx1, prfx2, prfx3);
-#endif                                  /* MVS */
-
    cname = salloc(makename(buf, SourceDir, buf1, CSuffix));
    if ((out_file = fopen(cname, "w")) == NULL)
       err2("cannot open output file ", cname);
    else
       addrmlst(cname, out_file);
-      
+
    prologue(); /* output standard comments and preprocessor directives */
 
    /*
@@ -1738,7 +1713,7 @@ struct node *n;
       if (by_ref)
          sym->id_type |= ByRef;
       }
-   
+
    if (fall_thru) {
       /*
        * Write declarations for any needed buffer parameters.
