@@ -20,76 +20,6 @@ char *ident = "ident";
  * Characters are used as token id's for single character tokens. The
  *  following table indicates which ones can be valid for RTL.
  */
-#if EBCDIC
-#define GoodChar(c) (good_char[c])
-static int good_char[256] = {
-   0  /* \000 */,   0  /* \001 */,   0  /* \002 */,   0  /* \003 */,
-   0  /* \004 */,   0  /* \005 */,   0  /* \006 */,   0  /* \007 */,
-   0  /* \010 */,   0  /* \011 */,   0  /* \012 */,   0  /* \013 */,
-   0  /* \014 */,   0  /* \015 */,   0  /* \016 */,   0  /* \017 */,
-   0  /* \020 */,   0  /* \021 */,   0  /* \022 */,   0  /* \023 */,
-   0  /* \024 */,   0  /* \025 */,   0  /* \026 */,   0  /* \027 */,
-   0  /* \030 */,   0  /* \031 */,   0  /* \032 */,   0  /* \033 */,
-   0  /* \034 */,   0  /* \035 */,   0  /* \036 */,   0  /* \037 */,
-   0  /* \040 */,   0  /* \041 */,   0  /* \042 */,   0  /* \043 */,
-   0  /* \044 */,   0  /* \045 */,   0  /* \046 */,   0  /* \047 */,
-   0  /* \050 */,   0  /* \051 */,   0  /* \052 */,   0  /* \053 */,
-   0  /* \054 */,   0  /* \055 */,   0  /* \056 */,   0  /* \057 */,
-   0  /* \060 */,   0  /* \061 */,   0  /* \062 */,   0  /* \063 */,
-   0  /* \064 */,   0  /* \065 */,   0  /* \066 */,   0  /* \067 */,
-   0  /* \070 */,   0  /* \071 */,   0  /* \072 */,   0  /* \073 */,
-   0  /* \074 */,   0  /* \075 */,   0  /* \076 */,   0  /* \077 */,
-   0  /*      */,   0  /* \101 */,   0  /* \102 */,   0  /* \103 */,
-   0  /* \104 */,   0  /* \105 */,   0  /* \106 */,   0  /* \107 */,
-   0  /* \110 */,   0  /* \111 */,   0  /* \112 */,   1  /*  .   */,
-   1  /*  <   */,   1  /*  (   */,   1  /*  +   */,   1  /*  |   */,
-   1  /*  &   */,   0  /* \121 */,   0  /* \122 */,   0  /* \123 */,
-   0  /* \124 */,   0  /* \125 */,   0  /* \126 */,   0  /* \127 */,
-   0  /* \130 */,   0  /* \131 */,   1  /*  !   */,   0  /*  $   */,
-   1  /*  *   */,   1  /*  )   */,   1  /*  ;   */,   1  /*  ^   */,
-   1  /*  -   */,   1  /*  /   */,   0  /* \142 */,   0  /* \143 */,
-   0  /* \144 */,   0  /* \145 */,   0  /* \146 */,   0  /* \147 */,
-   0  /* \150 */,   0  /* \151 */,   0  /* \152 */,   1  /*  ,   */,
-   1  /*  %   */,   0  /*  _   */,   1  /*  >   */,   1  /*  ?   */,
-   0  /* \160 */,   0  /* \161 */,   0  /* \162 */,   0  /* \163 */,
-   0  /* \164 */,   0  /* \165 */,   0  /* \166 */,   0  /* \167 */,
-   0  /* \170 */,   0  /*  `   */,   1  /*  :   */,   0  /*  #   */,
-   0  /*  @   */,   0  /*  '   */,   1  /*  =   */,   0  /*  "   */,
-   0  /* \200 */,   0  /*  a   */,   0  /*  b   */,   0  /*  c   */,
-   0  /*  d   */,   0  /*  e   */,   0  /*  f   */,   0  /*  g   */,
-   0  /*  h   */,   0  /*  i   */,   0  /* \212 */,   0  /* \213 */,
-   0  /* \214 */,   0  /* \215 */,   0  /* \216 */,   0  /* \217 */,
-   0  /* \220 */,   0  /*  j   */,   0  /*  k   */,   0  /*  l   */,
-   0  /*  m   */,   0  /*  n   */,   0  /*  o   */,   0  /*  p   */,
-   0  /*  q   */,   0  /*  r   */,   0  /* \232 */,   0  /* \233 */,
-   0  /* \234 */,   0  /* \235 */,   0  /* \236 */,   0  /* \237 */,
-   0  /* \240 */,   1  /*  ~   */,   0  /*  s   */,   0  /*  t   */,
-   0  /*  u   */,   0  /*  v   */,   0  /*  w   */,   0  /*  x   */,
-   0  /*  y   */,   0  /*  z   */,   0  /* \252 */,   0  /* \253 */,
-   0  /* \254 */,   1  /*  [   */,   0  /* \256 */,   0  /* \257 */,
-   0  /* \260 */,   0  /* \261 */,   0  /* \262 */,   0  /* \263 */,
-   0  /* \264 */,   0  /* \265 */,   0  /* \266 */,   0  /* \267 */,
-   0  /* \270 */,   0  /* \271 */,   0  /* \272 */,   0  /* \273 */,
-   0  /* \274 */,   1  /*  ]   */,   0  /* \276 */,   0  /* \277 */,
-   1  /*  {   */,   0  /*  A   */,   0  /*  B   */,   0  /*  C   */,
-   0  /*  D   */,   0  /*  E   */,   0  /*  F   */,   0  /*  G   */,
-   0  /*  H   */,   0  /*  I   */,   0  /* \312 */,   0  /* \313 */,
-   0  /* \314 */,   0  /* \315 */,   0  /* \316 */,   0  /* \317 */,
-   1  /*  }   */,   0  /*  J   */,   0  /*  K   */,   0  /*  L   */,
-   0  /*  M   */,   0  /*  N   */,   0  /*  O   */,   0  /*  P   */,
-   0  /*  Q   */,   0  /*  R   */,   0  /* \332 */,   0  /* \333 */,
-   0  /* \334 */,   0  /* \335 */,   0  /* \336 */,   0  /* \337 */,
-   1  /*  \\  */,   0  /* \341 */,   0  /*  S   */,   0  /*  T   */,
-   0  /*  U   */,   0  /*  V   */,   0  /*  W   */,   0  /*  X   */,
-   0  /*  Y   */,   0  /*  Z   */,   0  /* \352 */,   0  /* \353 */,
-   0  /* \354 */,   0  /* \355 */,   0  /* \356 */,   0  /* \357 */,
-   0  /*  0   */,   0  /*  1   */,   0  /*  2   */,   0  /*  3   */,
-   0  /*  4   */,   0  /*  5   */,   0  /*  6   */,   0  /*  7   */,
-   0  /*  8   */,   0  /*  9   */,   0  /* \372 */,   0  /* \373 */,
-   0  /* \374 */,   0  /* \375 */,   0  /* \376 */,   0  /* \377 */,
-   };
-
-#else					/* EBCDIC */
 
 #define GoodChar(c) ((c) < 127 && good_char[c])
 static int good_char[128] = {
@@ -126,7 +56,6 @@ static int good_char[128] = {
    0  /*  x   */,   0  /*  y   */,   0  /*  z   */,   1  /*  {   */,
    1  /*  |   */,   1  /*  }   */,   1  /*  ~   */,   0  /*  \d  */
    };
-#endif					/* EBCDIC */
 
 /*
  * init_lex - initialize lexical analyzer.
@@ -423,10 +352,5 @@ int yylex()
          errt2(yylval.t, "invalid character: ", yylval.t->image);
       }
 
-#if EBCDIC
-   if (yylval.t->tok_id < 256)
-      return FromEBCDIC[yylval.t->tok_id];
-#endif
-
    return yylval.t->tok_id;
    }
