@@ -61,13 +61,7 @@ function{1} abs(n)
          return real
          }
       inline {
-
-#if SASC 
-         return C_double __builtin_fabs(n);
-#else
          return C_double Abs(n);
-#endif					/* SASC */
-
          }
       }
    else
@@ -210,7 +204,7 @@ function{0,1} proc(x,i)
             irunerr(205, i);
             errorfail;
             }
-         }   
+         }
 
       abstract {
          return proc
@@ -233,7 +227,7 @@ function{0,1} proc(x,i)
 	    }
 
 	 ENTERPSTATE(prog);
-#endif						/* MultiThread */
+#endif					/* MultiThread */
 
          /*
           * Attempt to convert Arg0 to a procedure descriptor using i to
@@ -248,7 +242,7 @@ function{0,1} proc(x,i)
 
 #ifdef MultiThread
 	 ENTERPSTATE(savedprog);
-#endif						/* MultiThread */
+#endif					/* MultiThread */
          if (prc == NULL)
             fail;
          else
