@@ -19,19 +19,19 @@
 #ifdef LoadFunc
 
 #ifndef RTLD_LAZY	/* normally from <dlfcn.h> */
-#define RTLD_LAZY 1
+   #define RTLD_LAZY 1
 #endif					/* RTLD_LAZY */
 
 #ifdef FreeBSD
    /*
-    * If DL_GETERRNO exists, this is an FreeBSD 1.1.5 or 2.0 
+    * If DL_GETERRNO exists, this is an FreeBSD 1.1.5 or 2.0
     * which lacks dlerror(); supply a substitute.
     */
    #passthru #ifdef DL_GETERRNO
       char *dlerror(void)
       {
          int no;
-   
+
          if (0 == dlctl(NULL, DL_GETERRNO, &no))
             return(strerror(no));
          else
@@ -61,7 +61,7 @@ function{0,1} loadfunc(filename,funcname)
       static char *curfile;
       static void *handle;
       char *funcname2;
-   
+
       /*
        * Get a library handle, reusing it over successive calls.
        */
@@ -186,7 +186,7 @@ continuation succ_cont;
    RunErr(status, &r);			/* error, with value */
    }
 
-#else						/* COMPILER */
+#else					/* COMPILER */
 
 int glue(argc, dargv)
 int argc;
@@ -216,8 +216,6 @@ dptr dargv;
    RunErr(status, &r);			/* error, with value */
    }
 
-#endif						/* COMPILER */
+#endif					/* COMPILER */
 
-#else						/* LoadFunc */
-static char junk;			/* avoid empty module */
-#endif						/* LoadFunc */
+#endif					/* LoadFunc */
