@@ -58,17 +58,17 @@ function{1} callout(x[nargs])
          if (retval == NULL)
             runerr(signal);
          else
-            runerr(signal, *retval); 
+            runerr(signal, *retval);
          }
       if (retval != NULL) {
          return *retval;
          }
-      else 
+      else
          fail;
       }
 end
 
-#endif 					/* ExternalFunctions */
+#endif					/* ExternalFunctions */
 #endif					/* !COMPILER */
 
 
@@ -86,7 +86,7 @@ function{1} char(i)
          irunerr(205, i);
          errorfail;
          }
-      return string(1, (char *)&allchars[FromAscii(i) & 0xFF]);
+      return string(1, (char *)&allchars[i & 0xFF]);
       }
 end
 
@@ -97,7 +97,7 @@ end
 function{1} collect(region, bytes)
 
    if !def:C_integer(region, (C_integer)0) then
-      runerr(101, region) 
+      runerr(101, region)
    if !def:C_integer(bytes, (C_integer)0) then
       runerr(101, bytes)
 
@@ -268,27 +268,6 @@ function{1} copy(x)
          }
 
       default: body {
-#if Never
-         if (Type(x) == T_External) {
-            word n;
-            tended union block *op, *bp;
-
-            /*
-             * Duplicate the block.  Recover number of data words in block,
-             * then allocate new block and copy the data.
-             */
-            op = BlkLoc(x);
-            n = (op->externl.blksize - (sizeof(struct b_external) - 
-                 sizeof(word))) / sizeof(word);
-            Protect(bp = (union block *)alcextrnl(n), runerr(0));
-            while (n--)
-               bp->externl.exdata[n] = op->externl.exdata[n];
-            result.dword = D_External;
-            BlkLoc(result) = bp;
-	    return result;
-            }
-         else
-#endif					/* Never */
             runerr(123,x);
          }
          }
@@ -327,7 +306,7 @@ function{1} display(i,f)
          ce = (struct b_coexpr *)BlkLoc(c);
       savedprog = curpstate;
       }
-#endif						/* MultiThread */
+#endif					/* MultiThread */
 
    abstract {
       return null
@@ -344,7 +323,7 @@ function{1} display(i,f)
        * Produce error if file cannot be written.
        */
       std_f = BlkLoc(f)->file.fd;
-      if ((BlkLoc(f)->file.status & Fs_Write) == 0) 
+      if ((BlkLoc(f)->file.status & Fs_Write) == 0)
          runerr(213, f);
 
       /*
@@ -369,7 +348,7 @@ function{1} display(i,f)
 	 ENTERPSTATE(savedprog);
        }
       else
-#endif						/* MultiThread */
+#endif					/* MultiThread */
          r = xdisp(pfp, glbl_argp, (int)i, std_f);
       if (r == Failed)
          runerr(305);
@@ -578,7 +557,7 @@ function{1} ord(s)
    body {
       if (StrLen(s) != 1)
          runerr(205, s);
-      return C_integer ToAscii(*StrLoc(s) & 0xFF);
+      return C_integer (*StrLoc(s) & 0xFF);
       }
 end
 
@@ -590,9 +569,9 @@ function{1} name(underef v, c)
    declare {
       struct progstate *prog, *savedprog;
       }
-#else						/* MultiThread */
+#else					/* MultiThread */
 function{1} name(underef v)
-#endif						/* MultiThread */
+#endif					/* MultiThread */
    /*
     * v must be a variable
     */
@@ -621,12 +600,12 @@ function{1} name(underef v)
          }
 
       ENTERPSTATE(prog);
-#endif						/* MultiThread */
+#endif					/* MultiThread */
       i = get_name(&v, &result);		/* return val ? #%#% */
 
 #ifdef MultiThread
       ENTERPSTATE(savedprog);
-#endif						/* MultiThread */
+#endif					/* MultiThread */
 
       if (i == Error)
          runerr(0);
@@ -646,7 +625,7 @@ function{} runerr(i,x[n])
          irunerr(205,i);
          errorfail;
          }
-      if (n == 0) 
+      if (n == 0)
          runerr((int)i);
       else
          runerr((int)i, x[0]);
@@ -1425,10 +1404,10 @@ function{0,1} variable(s)
 	 glbl_argp = pfp->pf_argp;
 	 pfp = pfp->pf_pfp;
          }
-#endif						/* MultiThread */
+#endif					/* MultiThread */
 
       rv = getvar(s, &result);
-   
+
 #ifdef MultiThread
       if (is:coexpr(c)) {
 	 ENTERPSTATE(savedprog);
@@ -1439,7 +1418,7 @@ function{0,1} variable(s)
 	    Deref(result);
 	    }
 	 }
-#endif						/* MultiThread */
+#endif					/* MultiThread */
 
       if (rv != Failed)
          return result;
@@ -1529,7 +1508,7 @@ function{*} localnames(ce,i)
       struct pf_marker *thePfp = BlkLoc(d)->coexpr.es_pfp;
 
       if (thePfp == NULL) fail;
-      
+
       /*
        * Produce error if i is negative
        */
@@ -1544,7 +1523,7 @@ function{*} localnames(ce,i)
          }
 
       arg = &((dptr)thePfp)[-(thePfp->pf_nargs) - 1];
-      cproc = (struct b_proc *)BlkLoc(arg[0]);    
+      cproc = (struct b_proc *)BlkLoc(arg[0]);
       for(j = 0; j < cproc->ndynam; j++) {
 	 result = cproc->lnames[j + cproc->nparam];
 	 suspend result;
@@ -1608,7 +1587,7 @@ function{*} staticnames(ce,i)
          }
 
       arg = &((dptr)thePfp)[-(thePfp->pf_nargs) - 1];
-      cproc = (struct b_proc *)BlkLoc(arg[0]);    
+      cproc = (struct b_proc *)BlkLoc(arg[0]);
       for(j=0; j < cproc->nstatic; j++) {
 	 result = cproc->lnames[j + cproc->nparam + cproc->ndynam];
 	 suspend result;
@@ -1671,7 +1650,7 @@ function{1,*} paramnames(ce,i)
          }
 
       arg = &((dptr)thePfp)[-(thePfp->pf_nargs) - 1];
-      cproc = (struct b_proc *)BlkLoc(arg[0]);    
+      cproc = (struct b_proc *)BlkLoc(arg[0]);
       for(j = 0; j < cproc->nparam; j++) {
 	 result = cproc->lnames[j];
 	 suspend result;
@@ -1796,10 +1775,6 @@ function{1} load(s,arglist,infile,outfile,errfile,
            &~((word)WordSize*StackAlign-1));
 #endif					/* UpStack */
 
-#ifdef CoProcesses
-      sblkp->cstate[1] = 0;
-#endif					/* CoProcesses */
-
       sblkp->es_argp = NULL;
       sblkp->es_gfp = NULL;
       pstate->Mainhead->freshblk = nulldesc;/* &main has no refresh block. */
