@@ -19,28 +19,6 @@ static void           vanq_proc (struct ef_marker *efp_v,
                                      struct gf_marker *gfp_v);
 #endif					/* EventMon */
 
-/*
- * The following code is operating-system dependent [@interp.01]. Declarations.
- */
-
-#if PORT
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA
-#if LATTICE
-extern int chkbreak;
-#endif					/* LATTICE */
-#endif					/* AMIGA */
-
-#if ARM || ATARI_ST || MACINTOSH || MSDOS || MVS || OS2 || UNIX || VM || VMS
-   /* nothing needed */
-#endif					/* ARM || ATARI_ST || ... */
-
-/*
- * End of operating-system specific code.
- */
-
 #ifndef MultiThread
 word lastop;			/* Last operator evaluated */
 #endif					/* MultiThread */
@@ -53,16 +31,6 @@ struct gf_marker *gfp;		/* Generator frame pointer */
 inst ipc;			/* Interpreter program counter */
 word *sp = NULL;		/* Stack pointer */
 
-
-#ifdef EventMon
-extern union { 			/* clock ticker -- keep in sync w/ fmonitor.r */
-   unsigned short s[16];	/* 16 counters */
-   unsigned long l[8];		/* 8 longs are easier to check */
-} ticker;
-extern unsigned long oldtick;	/* previous sum of the two longs */
-#endif					/* EventMon */
-
-
 int ilevel;			/* Depth of recursion in interp() */
 struct descrip value_tmp;	/* list argument to Op_Apply */
 struct descrip eret_tmp;	/* eret value during unwinding */
@@ -172,43 +140,14 @@ word xnargs;
  * Inside the interpreter loop, PushDesc, PushNull, PushAVal, and
  *  PushVal use rsp instead of sp for efficiency.
  */
-
 #undef PushDesc
 #undef PushNull
 #undef PushVal
 #undef PushAVal
-#define PushDesc(d)   {*++rsp=((d).dword); *++rsp=((d).vword.integr);}
-#define PushNull   {*++rsp = D_Null; *++rsp = 0;}
-#define PushVal(v)   {*++rsp = (word)(v);}
-
-/*
- * The following code is operating-system dependent [@interp.02].  Define
- *  PushAVal for computers that store longs and pointers differently.
- */
-
-#if PORT
-#define PushAVal(x) PushVal(x)
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA || ARM || ATARI_ST || MACINTOSH || MVS || UNIX || VM || VMS
-#define PushAVal(x) PushVal(x)
-#endif					/* AMIGA || ARM || ATARI_ST || ... */
-
-#if MSDOS || OS2
-#if HIGHC_386 || ZTC_386 || INTEL_386 || WATCOM || BORLAND_386 || SCCX_MX
-#define PushAVal(x) PushVal(x)
-#else					/* HIGHC_386 || ZTC_386 || ... */
-#define PushAVal(x) {rsp++; \
-		       stkword.stkadr = (char *)(x); \
-		       *rsp = stkword.stkint; \
-		       }
-#endif					/* HIGH_386 || ZTC_386 || ... */
-#endif					/* MSDOS || OS2 */
-
-/*
- * End of operating-system specific code.
- */
+#define PushDesc(d)   PushDescSP(rsp,d)
+#define PushNull      PushNullSP(rsp)
+#define PushVal(v)    PushValSP(rsp,v)
+#define PushAVal(a)   PushValSP(rsp,a)
 
 
 /*
@@ -249,7 +188,7 @@ dptr cargp;
     * nothing for invocation in a co-expression other than &main.
     */
    if (BlkLoc(k_current) == BlkLoc(k_main) &&
-      ((char *)sp + PerilDelta) > (char *)stackend) 
+      ((char *)sp + PerilDelta) > (char *)stackend)
          fatalerr(301, NULL);
 #endif					/* MultiThread */
 
@@ -319,11 +258,6 @@ dptr cargp;
    for (;;) {
 
 #ifdef EventMon
-#if UNIX
-      if (ticker.l[0] + ticker.l[1] + ticker.l[2] + ticker.l[3] +
-	  ticker.l[4] + ticker.l[5] + ticker.l[6] + ticker.l[7] != oldtick)
-	 InterpEVTick();
-#endif					/* UNIX */
 
    /*
     * Location change events are generated by checking to see if the opcode
@@ -333,8 +267,8 @@ dptr cargp;
     *  Further optimization here is planned.
     */
    if (!is:null(curpstate->eventmask) && (
-       Testb((word)ToAscii(E_Loc), curpstate->eventmask) ||
-       Testb((word)ToAscii(E_Line), curpstate->eventmask)
+       Testb((word)E_Loc, curpstate->eventmask) ||
+       Testb((word)E_Line, curpstate->eventmask)
        )) {
 
       if (InRange(code, ipc.opnd, ecode)) {
@@ -351,9 +285,9 @@ dptr cargp;
                pollctr = pollevent();
 	       EntInterp;
 	       if (pollctr == -1) fatalerr(141, NULL);
-	       }	       
+	       }
 #endif					/* Polling */
-#endif				/* LineCodes */
+#endif					/* LineCodes */
 
 
 	    if(current_line_ptr &&
@@ -361,7 +295,7 @@ dptr cargp;
 	       current_line_ptr[1].ipc < ipc_offset &&
 	       ipc_offset < current_line_ptr[2].ipc) {
 	       current_line_ptr ++;
-	       } 
+	       }
 	    else {
 	       current_line_ptr = ilines;
 	       size = DiffPtrs((char *)elines, (char *)ilines) /
@@ -379,13 +313,13 @@ dptr cargp;
 	    linenum = current_line_ptr->line;
             temp_no = linenum & 65535;
             if ((lastline & 65535) != temp_no) {
-               if (Testb((word)ToAscii(E_Line), curpstate->eventmask))
+               if (Testb((word)E_Line, curpstate->eventmask))
                      if (temp_no)
                         InterpEVVal(temp_no, E_Line);
 	       }
 	    if (lastline != linenum) {
 	       lastline = linenum;
-	       if (Testb((word)ToAscii(E_Loc), curpstate->eventmask) &&
+	       if (Testb((word)E_Loc, curpstate->eventmask) &&
 		   current_line_ptr->line >> 16)
 		  InterpEVVal(current_line_ptr->line, E_Loc);
 	       }
@@ -396,60 +330,15 @@ dptr cargp;
 
       lastop = GetOp;		/* Instruction fetch */
 
-#ifdef StackPic
-      ExInterp;
-      stkdump((int)lastop);
-      EntInterp;
-#endif					/* StackPic */
-
-/*
- * The following code is operating-system dependent [@interp.03].  Check
- *  for external event.
- */
-#if PORT
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA
-#if LATTICE
-      ExInterp;
-      if (chkbreak > 0)
-	 chkabort();			/* check for CTRL-C or CTRL-D break */
-      EntInterp;
-#endif					/* LATTICE */
-#endif					/* AMIGA */
-
-#if ARM || ATARI_ST || MSDOS || MVS || OS2 || UNIX || VM || VMS
-   /* nothing to do */
-#endif					/* ARM || ATARI_ST || ... */
-
-#if MACINTOSH
-#if MPW
-   {
-      #define CursorCheckInterval 800 /* virtual machine instructions */
-      void RotateTheCursor(void);
-      static short cursorcount = 1;
-      if (--cursorcount == 0) {
-	 RotateTheCursor();
-	 cursorcount = CursorCheckInterval;
-	 }
-   }
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
-/*
- * End of operating-system specific code.
- */
-
 #ifdef EventMon
       /*
        * If we've asked for ALL opcode events, or specifically for this one
        * generate an MT-style event.
        */
       if ((!is:null(curpstate->eventmask) &&
-	   Testb((word)ToAscii(E_Opcode), curpstate->eventmask)) &&
+	   Testb((word)E_Opcode, curpstate->eventmask)) &&
 	  (is:null(curpstate->opcodemask) ||
-	   Testb((word)ToAscii(lastop), curpstate->opcodemask))) {
+	   Testb((word)lastop, curpstate->opcodemask))) {
 	 ExInterp;
 	 MakeInt(lastop, &(curpstate->parent->eventval));
 	 actparent(E_Opcode);
@@ -477,7 +366,7 @@ Deliberate Syntax Error
 	    PushAVal(opnd);
 	    break;
 
-	 case Op_Acset: 	/* cset, absolute address */
+	 case Op_Acset:		/* cset, absolute address */
 	    PushVal(D_Cset);
 	    PushAVal(GetWord);
 	    break;
@@ -496,21 +385,15 @@ Deliberate Syntax Error
 	    PutWord(opnd);
 	    break;
 
-	 case Op_Areal: 	/* real, absolute address */
+	 case Op_Areal:		/* real, absolute address */
 	    PushVal(D_Real);
 	    PushAVal(GetWord);
 	    break;
 
 	 case Op_Str:		/* string */
 	    PutOp(Op_Astr);
-	    PushVal(GetWord)
-
-#ifdef CRAY
-	    opnd = (word)(strcons + GetWord);
-#else					/* CRAY */
+	    PushVal(GetWord);
 	    opnd = (word)strcons + GetWord;
-#endif					/* CRAY */
-
 	    PutWord(opnd);
 	    PushAVal(opnd);
 	    break;
@@ -540,7 +423,7 @@ Deliberate Syntax Error
 	    PushAVal(GetWord);
 	    break;
 
-	 case Op_Local: 	/* local */
+	 case Op_Local:		/* local */
 	    PushVal(D_Var);
 	    PushAVal(&pfp->pf_locals[GetWord]);
 	    break;
@@ -563,7 +446,7 @@ Deliberate Syntax Error
 
 				/* Unary operators */
 
-	 case Op_Compl: 	/* ~e */
+	 case Op_Compl:		/* ~e */
 	 case Op_Neg:		/* -e */
 	 case Op_Number:	/* +e */
 	 case Op_Refresh:	/* ^e */
@@ -572,7 +455,7 @@ Deliberate Syntax Error
 	    DerefArg(1);
 	    Call_Cond;
 
-	 case Op_Value: 	/* .e */
+	 case Op_Value:		/* .e */
             Setup_Op(1);
             DerefArg(1);
             Call_Cond;
@@ -604,28 +487,28 @@ Deliberate Syntax Error
 	 case Op_Cat:		/* e1 || e2 */
 	 case Op_Diff:		/* e1 -- e2 */
 	 case Op_Div:		/* e1 / e2 */
-	 case Op_Inter: 	/* e1 ** e2 */
+	 case Op_Inter:		/* e1 ** e2 */
 	 case Op_Lconcat:	/* e1 ||| e2 */
-	 case Op_Minus: 	/* e1 - e2 */
+	 case Op_Minus:		/* e1 - e2 */
 	 case Op_Mod:		/* e1 % e2 */
 	 case Op_Mult:		/* e1 * e2 */
-	 case Op_Power: 	/* e1 ^ e2 */
+	 case Op_Power:		/* e1 ^ e2 */
 	 case Op_Unions:	/* e1 ++ e2 */
 	 case Op_Plus:		/* e1 + e2 */
 	 case Op_Eqv:		/* e1 === e2 */
-	 case Op_Lexeq: 	/* e1 == e2 */
-	 case Op_Lexge: 	/* e1 >>= e2 */
-	 case Op_Lexgt: 	/* e1 >> e2 */
-	 case Op_Lexle: 	/* e1 <<= e2 */
-	 case Op_Lexlt: 	/* e1 << e2 */
-	 case Op_Lexne: 	/* e1 ~== e2 */
+	 case Op_Lexeq:		/* e1 == e2 */
+	 case Op_Lexge:		/* e1 >>= e2 */
+	 case Op_Lexgt:		/* e1 >> e2 */
+	 case Op_Lexle:		/* e1 <<= e2 */
+	 case Op_Lexlt:		/* e1 << e2 */
+	 case Op_Lexne:		/* e1 ~== e2 */
 	 case Op_Neqv:		/* e1 ~=== e2 */
-	 case Op_Numeq: 	/* e1 = e2 */
-	 case Op_Numge: 	/* e1 >= e2 */
-	 case Op_Numgt: 	/* e1 > e2 */
-	 case Op_Numle: 	/* e1 <= e2 */
-	 case Op_Numne: 	/* e1 ~= e2 */
-	 case Op_Numlt: 	/* e1 < e2 */
+	 case Op_Numeq:		/* e1 = e2 */
+	 case Op_Numge:		/* e1 >= e2 */
+	 case Op_Numgt:		/* e1 > e2 */
+	 case Op_Numle:		/* e1 <= e2 */
+	 case Op_Numne:		/* e1 ~= e2 */
+	 case Op_Numlt:		/* e1 < e2 */
 	    Setup_Op(2);
 	    DerefArg(1);
 	    DerefArg(2);
@@ -640,17 +523,17 @@ Deliberate Syntax Error
 	    Setup_Op(3);
 	    Call_Cond;
 
-	 case Op_Subsc: 	/* e1[e2] */
+	 case Op_Subsc:		/* e1[e2] */
 	    PushNull;
 	    Setup_Op(3);
 	    Call_Cond;
 				/* Generative binary operators */
 
-	 case Op_Rasgn: 	/* e1 <- e2 */
+	 case Op_Rasgn:		/* e1 <- e2 */
 	    Setup_Op(2);
 	    Call_Gen;
 
-	 case Op_Rswap: 	/* e1 <-> e2 */
+	 case Op_Rswap:		/* e1 <-> e2 */
 	    PushNull;
 	    Setup_Op(3);
 	    Call_Gen;
@@ -679,11 +562,11 @@ Deliberate Syntax Error
                pollctr = pollevent();
 	       EntInterp;
 	       if (pollctr == -1) fatalerr(141, NULL);
-	       }	       
+	       }
 #endif					/* Polling */
 
 
-#endif				/* LineCodes */
+#endif					/* LineCodes */
 
             break;
 
@@ -710,11 +593,11 @@ Deliberate Syntax Error
                pollctr = pollevent();
 	       EntInterp;
 	       if (pollctr == -1) fatalerr(141, NULL);
-	       }	       
+	       }
 #endif					/* Polling */
 
 
-#endif				/* LineCodes */
+#endif					/* LineCodes */
 
 #ifdef EventMon
             linenum = GetWord;
@@ -725,7 +608,7 @@ Deliberate Syntax Error
 
 				/* ---String Scanning--- */
 
-	 case Op_Bscan: 	/* prepare for scanning */
+	 case Op_Bscan:		/* prepare for scanning */
 	    PushDesc(k_subject);
 	    PushVal(D_Integer);
 	    PushVal(k_pos);
@@ -735,7 +618,7 @@ Deliberate Syntax Error
 
 	    goto C_rtn_term;
 
-	 case Op_Escan: 	/* exit from scanning */
+	 case Op_Escan:		/* exit from scanning */
 	    Setup_Arg(1);
 
 	    signal = Oescan(1,rargp);
@@ -779,7 +662,7 @@ Deliberate Syntax Error
                            j = bp->lelem.first + i;
                            if (j >= bp->lelem.nslots)
                               j -= bp->lelem.nslots;
-                           PushDesc(bp->lelem.lslots[j])
+                           PushDesc(bp->lelem.lslots[j]);
                            }
                         }
 		  goto invokej;
@@ -790,7 +673,7 @@ Deliberate Syntax Error
                   bp = BlkLoc(value_tmp);
                   args = bp->record.recdesc->proc.nfields;
                   for (i = 0; i < args; i++) {
-                     PushDesc(bp->record.fields[i])
+                     PushDesc(bp->record.fields[i]);
                      }
                   goto invokej;
                   }
@@ -833,7 +716,7 @@ invokej:
                   pollctr = pollevent();
 	          EntInterp;
 	          if (pollctr == -1) fatalerr(141, NULL);
-	          }	       
+	          }
 #endif					/* Polling */
 
 #ifdef EventMon
@@ -887,7 +770,7 @@ invokej:
 	    }
 	    }
 
-	 case Op_Keywd: 	/* keyword */
+	 case Op_Keywd:		/* keyword */
 
             PushNull;
             opnd = GetWord;
@@ -896,7 +779,7 @@ invokej:
 	    signal = (*(keytab[(int)opnd]))(rargp);
 	    goto C_rtn_term;
 
-	 case Op_Llist: 	/* construct list */
+	 case Op_Llist:		/* construct list */
 	    opnd = GetWord;
 
 #ifdef EventMon
@@ -932,7 +815,7 @@ invokej:
 	    newefp->ef_failure.opnd = (word *)opnd;
 	    goto mark;
 
-	 case Op_Amark: 	/* mark with absolute fipc */
+	 case Op_Amark:		/* mark with absolute fipc */
 	    newefp = (struct ef_marker *)(rsp + 1);
 	    newefp->ef_failure.opnd = (word *)GetWord;
 mark:
@@ -944,7 +827,7 @@ mark:
 	    gfp = 0;
 	    break;
 
-	 case Op_Mark0: 	/* create expression frame with 0 ipl */
+	 case Op_Mark0:		/* create expression frame with 0 ipl */
 mark0:
 	    newefp = (struct ef_marker *)(rsp + 1);
 	    newefp->ef_failure.opnd = 0;
@@ -1313,7 +1196,7 @@ Pret_uw:
 
 	       return A_Pret_uw;
 	       }
-	   
+
 #ifdef EventMon
 	   if (!is:proc(oldargp) && is:proc(unwinder))
 	      oldargp = unwinder;
@@ -1525,7 +1408,7 @@ Pfail_uw:
 	    }
 				/* ---Odds and Ends--- */
 
-	 case Op_Ccase: 	/* case clause */
+	 case Op_Ccase:		/* case clause */
 	    PushNull;
 	    PushVal(((word *)efp)[-2]);
 	    PushVal(((word *)efp)[-1]);
@@ -1544,7 +1427,7 @@ Pfail_uw:
 	    rsp += 2;
 	    break;
 
-	 case Op_Field: 	/* e1.e2 */
+	 case Op_Field:		/* e1.e2 */
 	    PushVal(D_Integer);
 	    PushVal(GetWord);
 	    Setup_Arg(2);
@@ -1561,25 +1444,19 @@ Pfail_uw:
 	    ipc.opnd = (word *)opnd;
 	    break;
 
-	 case Op_Agoto: 	/* goto absolute address */
+	 case Op_Agoto:		/* goto absolute address */
 	    opnd = GetWord;
 	    ipc.opnd = (word *)opnd;
 	    break;
 
 	 case Op_Init:		/* initial */
 	    *--ipc.op = Op_Goto;
-
-#ifdef CRAY
-	    opnd = (sizeof(*ipc.op) + sizeof(*rsp))/8;
-#else					/* CRAY */
 	    opnd = sizeof(*ipc.op) + sizeof(*rsp);
-#endif					/* CRAY */
-
 	    opnd += (word)ipc.opnd;
 	    ipc.opnd = (word *)opnd;
 	    break;
 
-	 case Op_Limit: 	/* limit */
+	 case Op_Limit:		/* limit */
 	    Setup_Arg(0);
 
 	    if (Olimit(0,rargp) == A_Resume) {
@@ -1602,12 +1479,12 @@ Pfail_uw:
 	    goto mark0;
 
 #ifdef TallyOpt
-	 case Op_Tally: 	/* tally */
+	 case Op_Tally:		/* tally */
 	    tallybin[GetWord]++;
 	    break;
 #endif					/* TallyOpt */
 
-	 case Op_Pnull: 	/* push null descriptor */
+	 case Op_Pnull:		/* push null descriptor */
 	    PushNull;
 	    break;
 
@@ -1615,7 +1492,7 @@ Pfail_uw:
 	    rsp -= 2;
 	    break;
 
-	 case Op_Push1: 	/* push integer 1 */
+	 case Op_Push1:		/* push integer 1 */
 	    PushVal(D_Integer);
 	    PushVal(1);
 	    break;
@@ -1654,7 +1531,7 @@ Pfail_uw:
 #ifndef Coexpr
             err_msg(401, NULL);
             goto efail;
-#else                                        /* Coexpr */
+#else					/* Coexpr */
             struct b_coexpr *ncp;
             dptr dp;
 
@@ -1684,7 +1561,7 @@ Pfail_uw:
 
 #ifndef Coexpr
             syserr("co-expression return, but co-expressions not implemented");
-#else                                        /* Coexpr */
+#else					/* Coexpr */
             struct b_coexpr *ncp;
 
             ExInterp;
@@ -1702,7 +1579,7 @@ Pfail_uw:
 
 #ifndef Coexpr
             syserr("co-expression failure, but co-expressions not implemented");
-#else                                        /* Coexpr */
+#else					/* Coexpr */
             struct b_coexpr *ncp;
 
             ExInterp;
@@ -1814,95 +1691,6 @@ interp_quit:
    return 0;	/* avoid gcc warning */
    }
 
-#ifdef StackPic
-/*
- * The following code is operating-system dependent [@interp.04].
- *  Diagnostic stack pictures for debugging/monitoring.
- */
-
-#if PORT
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA || ATARI_ST || MACINTOSH || MVS || VM || VMS
-   /* not included */
-#endif					/* AMIGA || ATARI_ST || ... */
-
-#if ARM
-void stkdump(op)
-   int op;
-   {
-   word *stk;
-   word *i;
-   stk = (word *)BlkLoc(k_current);
-   stk += Wsizeof(struct b_coexpr);
-   fprintf(stderr,">  stack:  %.8x\n", (word)stk);
-   fprintf(stderr,">  sp:     %.8x\n", (word)sp);
-   fprintf(stderr,">  pfp:    %.8x\n", (word)pfp);
-   fprintf(stderr,">  efp:    %.8x\n", (word)efp);
-   fprintf(stderr,">  gfp:    %.8x\n", (word)gfp);
-   fprintf(stderr,">  ipc:    %.8x\n", (word)ipc.op);
-   fprintf(stderr,">  argp:   %.8x\n", (word)glbl_argp);
-   fprintf(stderr,">  ilevel: %.8x\n", (word)ilevel);
-   fprintf(stderr,">  op:     %d\n",    (int)op);
-   for (i = stk; i <= (word *)sp; i++)
-      fprintf(stderr,"> %.8x\n",(word)*i);
-   fprintf(stderr,"> ----------\n");
-   fflush(stderr);
-   }
-#endif					/* ARM */
-
-#if MSDOS || OS2
-#if MICROSOFT || TURBO || BORLAND_286 || BORLAND_386
-void stkdump(op)
-   int op;
-   {
-   word far *stk;
-   word far *i;
-   stk = (word far *)BlkLoc(k_current);
-   stk += Wsizeof(struct b_coexpr);
-   fprintf(stderr,">  stack:  %08lx\n", (word)stk);
-   fprintf(stderr,">  sp:     %08lx\n", (word)sp);
-   fprintf(stderr,">  pfp:    %08lx\n", (word)pfp);
-   fprintf(stderr,">  efp:    %08lx\n", (word)efp);
-   fprintf(stderr,">  gfp:    %08lx\n", (word)gfp);
-   fprintf(stderr,">  ipc:    %08lx\n", (word)ipc.op);
-   fprintf(stderr,">  argp:   %08lx\n", (word)glbl_argp);
-   fprintf(stderr,">  ilevel: %08lx\n", (word)ilevel);
-   fprintf(stderr,">  op:     %d\n",    (int)op);
-   for (i = stk; i <= (word far *)sp; i++)
-      fprintf(stderr,"> %08lx\n",(word)*i);
-   fprintf(stderr,"> ----------\n");
-   fflush(stderr);
-   }
-#endif					/* MICROSOFT || TURBO ... */
-#endif					/* MSDOS || OS2 */
-
-#if UNIX || VMS
-void stkdump(op)
-   int op;
-   {
-   word *i;
-   fprintf(stderr,"\001stack: %lx\n",(long)(stack + Wsizeof(struct b_coexpr)));
-   fprintf(stderr,"\001pfp: %lx\n",(long)pfp);
-   fprintf(stderr,"\001efp: %lx\n",(long)efp);
-   fprintf(stderr,"\001gfp: %lx\n",(long)gfp);
-   fprintf(stderr,"\001ipc: %lx\n",(long)ipc.op);
-   fprintf(stderr,"\001argp: %lx\n",(long)glbl_argp);
-   fprintf(stderr,"\001ilevel: %lx\n",(long)ilevel);
-   fprintf(stderr,"\001op: \%d\n",(int)op);
-   for (i = stack + Wsizeof(struct b_coexpr); i <= sp; i++)
-      fprintf(stderr,"\001%lx\n",*i);
-   fprintf(stderr,"\001----------\n");
-   fflush(stderr);
-   }
-#endif					/* UNIX || VMS */
-
-/*
- * End of operating-system specific code.
- */
-#endif					/* StackPic */
-
 #ifdef EventMon
 /*
  * vanq_proc - monitor the removal of suspended operations from within
@@ -2009,27 +1797,6 @@ register struct b_coexpr *ncp;
       ccp->tvalloc = savedtvalloc;
       }
 
-   /*
-    * flush any accumulated ticks
-    */
-#ifdef EventMon
-#if UNIX
-   if (ticker.l[0] + ticker.l[1] + ticker.l[2] + ticker.l[3] +
-       ticker.l[4] + ticker.l[5] + ticker.l[6] + ticker.l[7] != oldtick) {
-      word sum, nticks;
-
-      oldtick = ticker.l[0] + ticker.l[1] + ticker.l[2] + ticker.l[3] +
-       ticker.l[4] + ticker.l[5] + ticker.l[6] + ticker.l[7];
-      sum = ticker.s[0] + ticker.s[1] + ticker.s[2] + ticker.s[3] +
-	 ticker.s[4] + ticker.s[5] + ticker.s[6] + ticker.s[7] +
-	    ticker.s[8] + ticker.s[9] + ticker.s[10] + ticker.s[11] +
-	       ticker.s[12] + ticker.s[13] + ticker.s[14] + ticker.s[15];
-      nticks = sum - oldsum;
-      oldsum = sum;
-      }
-#endif					/* UNIX */
-#endif					/* EventMon */
-
    return rv;
 }
 
@@ -2043,7 +1810,7 @@ int event;
    struct progstate *parent = curpstate->parent;
 
    StrLen(parent->eventcode) = 1;
-   StrLoc(parent->eventcode) = (char *)&allchars[FromAscii(event)&0xFF];
+   StrLoc(parent->eventcode) = (char *)&allchars[event & 0xFF];
    mt_activate(&(parent->eventcode), NULL,
 	       (struct b_coexpr *)curpstate->parent->Mainhead);
    }
