@@ -5,7 +5,7 @@
  *  After adding keywords, be sure to rerun ../icont/mkkwd.
  */
 
-#define KDef(p,n) int Cat(K,p) Params((dptr cargp));
+#define KDef(p,n) int Cat(K,p) (dptr cargp);
 #include "../h/kdefs.h"
 #undef KDef
 
@@ -29,11 +29,13 @@ keyword{1} clock
       return string
       }
    inline {
-      struct cal_time ct;
+      time_t t;
+      struct tm *ct;
       char sbuf[9], *tmp;
 
-      getitime(&ct);
-      sprintf(sbuf,"%02d:%02d:%02d", ct.hour, ct.minute, ct.second);
+      time(&t);
+      ct = localtime(&t);
+      sprintf(sbuf,"%02d:%02d:%02d", ct->tm_hour, ct->tm_min, ct->tm_sec);
       Protect(tmp = alcstr(sbuf,(word)8), runerr(0));
       return string(8, tmp);
       }
@@ -89,11 +91,14 @@ keyword{1} date
       return string
       }
    inline {
-      struct cal_time ct;
+      time_t t;
+      struct tm *ct;
       char sbuf[11], *tmp;
 
-      getitime(&ct);
-      sprintf(sbuf, "%04d/%02d/%02d", ct.year, ct.month_no, ct.mday);
+      time(&t);
+      ct = localtime(&t);
+      sprintf(sbuf, "%04d/%02d/%02d",
+         1900 + ct->tm_year, ct->tm_mon + 1, ct->tm_mday);
       Protect(tmp = alcstr(sbuf,(word)10), runerr(0));
       return string(10, tmp);
       }
@@ -105,14 +110,24 @@ keyword{1} dateline
       return string
       }
    body {
-      struct cal_time ct;
+      static char *day[] = {
+         "Sunday", "Monday", "Tuesday", "Wednesday",
+         "Thursday", "Friday", "Saturday"
+         };
+      static char *month[] = {
+         "January", "February", "March", "April", "May", "June",
+         "July", "August", "September", "October", "November", "December"
+         };
+      time_t t;
+      struct tm *ct;
       char sbuf[MaxCvtLen];
       int hour;
       char *merid, *tmp;
       int i;
 
-      getitime(&ct);
-      if ((hour = ct.hour) >= 12) {
+      time(&t);
+      ct = localtime(&t);
+      if ((hour = ct->tm_hour) >= 12) {
          merid = "pm";
          if (hour > 12)
             hour -= 12;
@@ -122,8 +137,9 @@ keyword{1} dateline
          if (hour < 1)
             hour += 12;
          }
-      sprintf(sbuf, "%s, %s %d, %d  %d:%02d %s", ct.wday, ct.month_nm,
-         ct.mday, ct.year, hour, ct.minute, merid);
+      sprintf(sbuf, "%s, %s %d, %d  %d:%02d %s", day[ct->tm_wday],
+         month[ct->tm_mon], ct->tm_mday, 1900 + ct->tm_year, hour,
+	 ct->tm_min, merid);
        i = strlen(sbuf);
        Protect(tmp = alcstr(sbuf, i), runerr(0));
        return string(i, tmp);
@@ -703,17 +719,6 @@ end
 
 "&ascii - a cset consisting of the 128 ascii characters"
 keyword{1} ascii
-#if EBCDIC == 1
-constant '\
-\x00\x01\x02\x03\x05\x07\x0b\x0c\x0d\x0e\x0f\x10\x11\x12\x13\x16\
-\x18\x19\x1c\x1d\x1e\x1f\x25\x26\x27\x2d\x2e\x2f\x32\x37\x3c\x3d\
-\x3f\x40\x4b\x4c\x4d\x4e\x4f\x50\x5a\x5b\x5c\x5d\x5e\x5f\x60\x61\
-\x6b\x6c\x6d\x6e\x6f\x79\x7a\x7b\x7c\x7d\x7e\x7f\x81\x82\x83\x84\
-\x85\x86\x87\x88\x89\x91\x92\x93\x94\x95\x96\x97\x98\x99\xa1\xa2\
-\xa3\xa4\xa5\xa6\xa7\xa8\xa9\xad\xbd\xc0\xc1\xc2\xc3\xc4\xc5\xc6\
-\xc7\xc8\xc9\xd0\xd1\xd2\xd3\xd4\xd5\xd6\xd7\xd8\xd9\xe0\xe2\xe3\
-\xe4\xe5\xe6\xe7\xe8\xe9\xf0\xf1\xf2\xf3\xf4\xf5\xf6\xf7\xf8\xf9'
-#else					/* EBCDIC == 1 */
 constant '\
 \000\001\002\003\004\005\006\007\010\011\012\013\014\015\016\017\
 \020\021\022\023\024\025\026\027\030\031\032\033\034\035\036\037\
@@ -723,7 +728,6 @@ constant '\
 \120\121\122\123\124\125\126\127\130\131\132\133\134\135\136\137\
 \140\141\142\143\144\145\146\147\150\151\152\153\154\155\156\157\
 \160\161\162\163\164\165\166\167\170\171\172\173\174\175\176\177'
-#endif					/* EBCDIC == 1 */
 end
 
 "&cset - a cset consisting of all the 256 characters."
