@@ -1,7 +1,7 @@
 /*
  * File: ocat.r -- caterr, lconcat
  */
-"x || y - concatenate strings x and y." 
+"x || y - concatenate strings x and y."
 
 operator{1} || cater(x, y)
 
@@ -87,8 +87,8 @@ operator{1} ||| lconcat(x, y)
       }
 
    body {
-      register struct b_list *bp1, *bp2;
-      register struct b_lelem *lp1, *lp2;
+      register struct b_list *bp1;
+      register struct b_lelem *lp1;
       word size1, size2, size3;
 
       /*
