@@ -88,14 +88,14 @@ struct astkblk *alcactiv()
    {
    struct astkblk *abp;
 
-   abp = (struct astkblk *)malloc((msize)sizeof(struct astkblk));
+   abp = (struct astkblk *)malloc(sizeof(struct astkblk));
 
    /*
     * If malloc failed, attempt to free some co-expression blocks and retry.
     */
    if (abp == NULL) {
       collect(Static);
-      abp = (struct astkblk *)malloc((msize)sizeof(struct astkblk));
+      abp = (struct astkblk *)malloc(sizeof(struct astkblk));
       }
 
    if (abp == NULL)
@@ -136,12 +136,7 @@ struct b_coexpr *alccoexp()
    {
    struct b_coexpr *ep;
    static int serial = 2; /* main co-expression is allocated elsewhere */
-
-#ifdef ATTM32
-   ep = (struct b_coexpr *)coexp_salloc(); /* 3B2/15/4000 stack */
-#else                                   /* ATTM32 */
-   ep = (struct b_coexpr *)malloc((msize)stksize);
-#endif                                  /* ATTM32 */
+   ep = (struct b_coexpr *)malloc(stksize);
 
    /*
     * If malloc failed or if there have been too many co-expression allocations
@@ -149,15 +144,8 @@ struct b_coexpr *alccoexp()
     */
 
    if (ep == NULL || alcnum > AlcMax) {
-
       collect(Static);
-
-#ifdef ATTM32           /* not needed, but here to play it safe */
-      ep = (struct b_coexpr *)coexp_salloc(); /* 3B2/15/4000 stack */
-#else                                   /* ATTM32 */
-      ep = (struct b_coexpr *)malloc((msize)stksize);
-#endif                                  /* ATTM32 */
-
+      ep = (struct b_coexpr *)malloc(stksize);
       }
 
    if (ep == NULL)
@@ -174,6 +162,8 @@ struct b_coexpr *alccoexp()
    ep->line_num = 0;
    ep->freshblk = nulldesc;
    ep->es_actstk = NULL;
+   ep->cstate[0] = 0;		/* zero the first two cstate words as a flag */
+   ep->cstate[1] = 0;
    stklist = ep;
    return ep;
    }
@@ -196,24 +186,16 @@ struct b_coexpr *alccoexp()
 
 #ifdef MultiThread
    if (icodesize > 0) {
-#ifdef ATTM32
-Deliberate Syntax Error
-#else					/* ATTM32 */
       ep = (struct b_coexpr *)
-	calloc(1, (msize)(stacksize+
+	calloc(1, stacksize+
 		       icodesize+
 		       sizeof(struct progstate)+
-		       sizeof(struct b_coexpr)));
-#endif					/* ATTM32 */
+		       sizeof(struct b_coexpr));
       }
    else
 #endif					/* MultiThread */
 
-#ifdef ATTM32
-   ep = (struct b_coexpr *)coexp_salloc(); /* 3B2/15/4000 stack */
-#else                                   /* ATTM32 */
-   ep = (struct b_coexpr *)malloc((msize)stksize);
-#endif                                  /* ATTM32 */
+   ep = (struct b_coexpr *)malloc(stksize);
 
    /*
     * If malloc failed or if there have been too many co-expression allocations
@@ -226,21 +208,13 @@ Deliberate Syntax Error
 
 #ifdef MultiThread
       if (icodesize>0) {
-#ifdef ATTM32
-Deliberate Syntax Error
-#else					/* ATTM32 */
          ep = (struct b_coexpr *)
-	    malloc((msize)(mstksize+icodesize+sizeof(struct progstate)));
-#endif					/* ATTM32 */
+	    malloc(mstksize+icodesize+sizeof(struct progstate));
          }
       else
 #endif					/* MultiThread */
 
-#ifdef ATTM32
-	 ep = (struct b_coexpr *)coexp_salloc(); /* 3B2/15/4000 stack */
-#else                                   /* ATTM32 */
-         ep = (struct b_coexpr *)malloc((msize)stksize);
-#endif                                  /* ATTM32 */
+         ep = (struct b_coexpr *)malloc(stksize);
       }
       if (ep == NULL)
          ReturnErrNum(305, NULL);
@@ -260,9 +234,11 @@ Deliberate Syntax Error
       ep->id = 1;
    else
 #endif					/* MultiThread */
-      ep->id = coexp_ser++;
+   ep->id = coexp_ser++;
    ep->nextstk = stklist;
    ep->es_tend = NULL;
+   ep->cstate[0] = 0;		/* zero the first two cstate words as a flag */
+   ep->cstate[1] = 0;
 
 #ifdef MultiThread
    /*
@@ -425,9 +401,9 @@ double val;
      *rp++ = *rq++;
      *rp   = *rq;
    }
-#else                                   /* Double */
+#else					/* Double */
    blk->realval = val;
-#endif                                  /* Double */
+#endif					/* Double */
 
    return blk;
    }
@@ -784,27 +760,13 @@ word nbytes,stdsize;
    uword minSize = MinAbrSize;
    struct region *rp;
 
-#if IntBits == 16
-   if ((uword)nbytes > (uword)MaxBlock)
-      return NULL;
-   if ((uword)stdsize > (uword)MaxBlock)
-      stdsize = (uword)MaxBlock;
-#endif					/* IntBits == 16 */
-
    if ((uword)nbytes > minSize)
       minSize = (uword)nbytes;
-
    rp = (struct region *)malloc(sizeof(struct region));
    if (rp) {
       rp->size = stdsize;
-#if IntBits == 16
-      if ((rp->size < nbytes) && (nbytes < (unsigned int)MaxBlock))
-         rp->size = Min(nbytes+stdsize,(unsigned int)MaxBlock);
-#else					/* IntBits == 16 */
       if (rp->size < nbytes)
          rp->size = Max(nbytes+stdsize, nbytes);
-#endif					/* IntBits == 16 */
-
       do {
          rp->free = rp->base = (char *)AllocReg(rp->size);
          if (rp->free != NULL) {
