@@ -77,8 +77,7 @@ extern int over_flow;
 
 /* DIG(struct b_bignum *b, word i): pointer to ith most significant digit */
 /*  (NOTE: This macro expansion often results in a very long string,
- *   that has been known to cause problems with the C compiler under VMS.
- *   So when DIG is used, keep it to one use per line.)
+ *   so when DIG is used, keep it to one use per line.)
  */
 
 #define DIG(b,i)     (&(b)->digits[(b)->msd+(i)])
@@ -96,9 +95,7 @@ extern int over_flow;
 
 /* copied from rconv.c */
 
-#if !EBCDIC
 #define tonum(c)     (isdigit(c) ? (c)-'0' : 10+(((c)|(040))-'a'))
-#endif					/* !EBCDIC */
 
 /* copied from oref.c */
 
@@ -108,41 +105,36 @@ extern int over_flow;
  * Prototypes.
  */
 
-hidden int mkdesc	Params((struct b_bignum *x, dptr dx));
-hidden novalue itobig	Params((word i, struct b_bignum *x, dptr dx));
+static int mkdesc	(struct b_bignum *x, dptr dx);
+static void itobig	(word i, struct b_bignum *x, dptr dx);
 
-hidden novalue decout	Params((FILE *f, DIGIT *n, word l));
+static void decout	(FILE *f, DIGIT *n, word l);
 
-hidden int bigaddi	Params((dptr da, word i, dptr dx));
-hidden int bigsubi	Params((dptr da, word i, dptr dx));
-hidden int bigmuli	Params((dptr da, word i, dptr dx));
-hidden int bigdivi	Params((dptr da, word i, dptr dx));
-hidden int bigmodi	Params((dptr da, word i, dptr dx));
-hidden int bigpowi	Params((dptr da, word i, dptr dx));
-hidden int bigpowii	Params((word a, word i, dptr dx));
-hidden word bigcmpi	Params((dptr da, word i));
+static int bigaddi	(dptr da, word i, dptr dx);
+static int bigsubi	(dptr da, word i, dptr dx);
+static int bigmuli	(dptr da, word i, dptr dx);
+static int bigdivi	(dptr da, word i, dptr dx);
+static int bigmodi	(dptr da, word i, dptr dx);
+static int bigpowi	(dptr da, word i, dptr dx);
+static int bigpowii	(word a, word i, dptr dx);
+static word bigcmpi	(dptr da, word i);
 
-hidden DIGIT add1	Params((DIGIT *u, DIGIT *v, DIGIT *w, word n));
-hidden word sub1	Params((DIGIT *u, DIGIT *v, DIGIT *w, word n));
-hidden novalue mul1	Params((DIGIT *u, DIGIT *v, DIGIT *w, word n, word m));
-hidden int div1	
-   Params((DIGIT *a, DIGIT *b, DIGIT *q, DIGIT *r, word m, word n, struct b_bignum *b1, struct b_bignum *b2));
-hidden novalue compl1	Params((DIGIT *u, DIGIT *w, word n));
-hidden word cmp1	Params((DIGIT *u, DIGIT *v, word n));
-hidden DIGIT addi1	Params((DIGIT *u, word k, DIGIT *w, word n));
-hidden novalue subi1	Params((DIGIT *u, word k, DIGIT *w, word n));
-hidden DIGIT muli1	Params((DIGIT *u, word k, int c, DIGIT *w, word n));
-hidden DIGIT divi1	Params((DIGIT *u, word k, DIGIT *w, word n));
-hidden DIGIT shifti1	Params((DIGIT *u, word k, DIGIT c, DIGIT *w, word n));
-hidden word cmpi1	Params((DIGIT *u, word k, word n));
+static DIGIT add1	(DIGIT *u, DIGIT *v, DIGIT *w, word n);
+static word sub1	(DIGIT *u, DIGIT *v, DIGIT *w, word n);
+static void mul1	(DIGIT *u, DIGIT *v, DIGIT *w, word n, word m);
+static int div1
+   (DIGIT *a, DIGIT *b, DIGIT *q, DIGIT *r, word m, word n, struct b_bignum *b1, struct b_bignum *b2);
+static void compl1	(DIGIT *u, DIGIT *w, word n);
+static word cmp1	(DIGIT *u, DIGIT *v, word n);
+static DIGIT addi1	(DIGIT *u, word k, DIGIT *w, word n);
+static void subi1	(DIGIT *u, word k, DIGIT *w, word n);
+static DIGIT muli1	(DIGIT *u, word k, int c, DIGIT *w, word n);
+static DIGIT divi1	(DIGIT *u, word k, DIGIT *w, word n);
+static DIGIT shifti1	(DIGIT *u, word k, DIGIT c, DIGIT *w, word n);
+static word cmpi1	(DIGIT *u, word k, word n);
 
-#ifdef SysMem
 #define bdzero(dest,l)  memset(dest, '\0', (l) * sizeof(DIGIT))
 #define bdcopy(src, dest, l)  memcpy(dest, src, (l) * sizeof(DIGIT))
-#else					/* SysMem */
-hidden novalue bdzero   Params((DIGIT *dest, word l));
-hidden novalue bdcopy   Params((DIGIT *src, DIGIT *dest, word l));
-#endif					/* SysMem */
 
 /*
  * mkdesc -- put value into a descriptor
@@ -190,7 +182,7 @@ dptr dx;
  *  i -> big
  */
 
-static novalue itobig(i, x, dx)
+static void itobig(i, x, dx)
 word i;
 struct b_bignum *x;
 dptr dx;
@@ -215,7 +207,7 @@ dptr dx;
       *DIG(x,0) = d;
       x->sign = 1;
       }
-            
+
    while (i != 0) {
       x->msd--;
       *DIG(x,0) = lo(i);
@@ -227,7 +219,7 @@ dptr dx;
 }
 
 /*
- *  string -> bignum 
+ *  string -> bignum
  */
 
 word bigradix(sign, r, s, end_s, result)
@@ -319,6 +311,7 @@ dptr da, dx;
    struct b_bignum *b;
    word i, blen;
    word d;
+   int sgn;
 
 #ifdef Double
 	{
@@ -335,7 +328,8 @@ dptr da, dx;
       return Succeeded;		/* got lucky; a simple integer suffices */
       }
 
-   x = x > 0 ? x : -x;
+   if (sgn = x < 0)
+      x = -x;
    blen = ln(x) / ln(B) + 0.99;
    for (i = 0; i < blen; i++)
       x /= B;
@@ -350,8 +344,8 @@ dptr da, dx;
       *DIG(b,i) = d;
       x -= d;
       }
-     
-   b->sign = x < 0;
+
+   b->sign = sgn;
    return mkdesc(b, dx);
 }
 
@@ -376,24 +370,12 @@ dptr da, dx;
           DIG(temp,0),
           alen);
    p = q += slen;
-#ifdef VMS
-   {
-      DIGIT *tempdg;
-      for (;;) {
-         tempdg = DIG(temp,0);
-         if (!cmpi1(tempdg, (word)0, alen))
-            break;
-         *--p = '0' + divi1(tempdg, (word)10, tempdg, alen);
-      }
-   }
-#else
    while (cmpi1(DIG(temp,0),
                 (word)0, alen))
       *--p = '0' + divi1(DIG(temp,0),
                          (word)10,
                          DIG(temp,0),
                          alen);
-#endif			/* VMS */
    if (a->sign)
       *--p = '-';
    StrLen(*dx) = q - p;
@@ -404,10 +386,10 @@ dptr da, dx;
 }
 
 /*
- *  bignum -> file 
+ *  bignum -> file
  */
 
-novalue bigprint(f, da)
+void bigprint(f, da)
 FILE *f;
 dptr da;
 {
@@ -421,7 +403,7 @@ dptr da;
       + log((double)blk->digits[blk->msd]) * 0.4342944819032518 + 0.5;
 						/* 1 / ln(10) */
    if (dlen >= MaxDigits) {
-      fprintf(f, "integer(~10^%ld)",dlen);
+      fprintf(f, "integer(~10^%ld)",(long)dlen);
       return;
       }
 
@@ -442,7 +424,7 @@ dptr da;
 /*
  * decout - given a base B digit string, print the number in base 10.
  */
-static novalue decout(f, n, l)
+static void decout(f, n, l)
 FILE *f;
 DIGIT *n;
 word l;
@@ -588,7 +570,7 @@ dptr dx;
 
 /*
  *  da - db -> dx
- */ 
+ */
 
 int bigsub(da, db, dx)
 dptr da, db, dx;
@@ -757,7 +739,7 @@ dptr da, db, dx;
       itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
       return bigsubi(&td, IntVal(*db), dx);
       }
-      
+
 }
 
 /*
@@ -800,14 +782,22 @@ dptr da, db, dx;
 /*
  *  da / db -> dx
  */
- 
+
 int bigdiv(da, db, dx)
 dptr da, db, dx;
 {
    tended struct b_bignum *a, *b, *x, *tu, *tv;
    word alen, blen;
+   struct descrip td;
+   char tdigits[INTBIGBLK];
 
-   if (Type(*da) == T_Lrgint && Type(*db) == T_Lrgint) {
+   /* Put *da into large integer format. */
+   if (Type(*da) != T_Lrgint) {
+      itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
+      da = &td;
+      }
+
+   if (Type(*db) == T_Lrgint) {         /* bignum / bignum */
       alen = LEN(LrgInt(da));
       blen = LEN(LrgInt(db));
       if (alen < blen) {
@@ -834,13 +824,8 @@ dptr da, db, dx;
       x->sign = a->sign ^ b->sign;
       return mkdesc(x, dx);
       }
-   else if (Type(*da) == T_Lrgint)     /* bignum / integer */
+   else                                 /* bignum / integer */
       return bigdivi(da, IntVal(*db), dx);
-   else if (Type(*db) == T_Lrgint) {   /* integer / bignum */
-      MakeInt(0, dx);
-      return Succeeded;
-      }
-   /* not called for integer / integer */
 }
 
 /*
@@ -852,8 +837,16 @@ dptr da, db, dx;
 {
    tended struct b_bignum *a, *b, *x, *temp, *tu, *tv;
    word alen, blen;
+   struct descrip td;
+   char tdigits[INTBIGBLK];
 
-   if (Type(*da) == T_Lrgint && Type(*db) == T_Lrgint) {
+   /* Put *da into large integer format. */
+   if (Type(*da) != T_Lrgint) {
+      itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
+      da = &td;
+      }
+
+   if (Type(*db) == T_Lrgint) {        /* bignum % bignum */
       alen = LEN(LrgInt(da));
       blen = LEN(LrgInt(db));
       if (alen < blen) {
@@ -884,17 +877,8 @@ dptr da, db, dx;
       x->sign = a->sign;
       return mkdesc(x, dx);
       }
-   else if (Type(*da) == T_Lrgint)     /* bignum % integer */
+   else				       /* bignum % integer */
       return bigmodi(da, IntVal(*db), dx);
-   else if (Type(*db) == T_Lrgint) {   /* integer % bignum */
-      struct descrip td;
-      char tdigits[INTBIGBLK];
-
-      itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
-      cpbignum(&td, dx);
-      return Succeeded;
-      }
-   /* not called for integer % integer */
 }
 
 /*
@@ -906,10 +890,18 @@ dptr da, dx;
 {
    struct descrip td;
    char tdigits[INTBIGBLK];
+   int cpstat;
 
-   itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
-   LrgInt(&td)->sign ^= 1;
-   return cpbignum(&td, dx);
+   /* Put *da into large integer format. */
+   if (Type(*da) != T_Lrgint) {
+      itobig(IntVal(*da), (struct b_bignum *)tdigits, &td);
+      da = &td;
+      }
+   LrgInt(da)->sign ^= 1;       /* Temporarily change the sign */
+   cpstat = cpbignum(da, dx);
+   LrgInt(da)->sign ^= 1;       /* Change it back */
+
+   return cpstat;
 }
 
 /*
@@ -919,41 +911,121 @@ dptr da, dx;
 int bigpow(da, db, dx)
 dptr da, db, dx;
 {
-   word n;
 
-   if (Type(*da) == T_Lrgint && Type(*db) == T_Lrgint) {
-      if (LrgInt(db)->sign) {
-         MakeInt(0, dx);
-         }
-      else {
-         n = LEN(LrgInt(db)) * NB;
-         /* scan bits left to right.  skip leading 1. */
-         while (--n >= 0)
-            if ((*DIG(LrgInt(db), n / NB) &
-                (1 << (n % NB))))
-               break;
-         /* then, for each zero, square the partial result;
-          *  for each one, square it and multiply it by a */
-         *dx = *da;
-         while (--n >= 0) {
-            if (bigmul(dx, dx, dx) == Error)
-	       return Error;
-            if ((*DIG(LrgInt(db), n / NB) &
-                (1 << (n % NB))))
-               if (bigmul(dx, da, dx) == Error)
-		  return Error;
+   if (Type(*db) == T_Lrgint) {
+      struct b_bignum *b;
+
+      b = LrgInt ( db );
+
+
+      if (Type(*da) == T_Lrgint) {
+	 if ( b->sign ) {
+	    /* bignum ^ -bignum = 0 */
+	    MakeInt ( 0, dx );
+	    return Succeeded;
 	    }
-         }
+	 else
+	    /* bignum ^ +bignum = guaranteed overflow */
+	    ReturnErrNum(307, Error);
+	 }
+      else if ( b->sign )
+	 /* integer ^ -bignum */
+	 switch ( IntVal ( *da ) ) {
+	    case 1:
+	       MakeInt ( 1, dx );
+	       return Succeeded;
+	    case -1:
+	       /* Result is +1 / -1, depending on whether *b is even or odd. */
+	       if ( ( b->digits[ b->lsd ] ) & 01 )
+		  MakeInt ( -1, dx );
+	       else
+		  MakeInt ( 1, dx );
+	       return Succeeded;
+	    case 0:
+	       ReturnErrNum(204,Error);
+	    default:
+	       /* da ^ (negative int) = 0 for all non-special cases */
+	       MakeInt(0, dx);
+	       return Succeeded;
+	    }
+      else {
+	 /* integer ^ +bignum */
+	 word n, blen;
+	 register DIGIT nth_dig, mask;
+
+	 b = LrgInt ( db );
+	 blen = LEN ( b );
+
+	 /* We scan the bits of b from the most to least significant.
+	  * The bit position in b is represented by the pair ( n, mask )
+	  * where n is the DIGIT number (0 = most sig.) and mask is the
+	  * the bit mask for the current bit.
+	  *
+	  * For each bit (most sig to least) in b,
+	  *  for each zero, square the partial result;
+	  *  for each one, square it and multiply it by a */
+	 MakeInt ( 1, dx );
+	 for ( n = 0; n < blen; ++n ) {
+	    nth_dig = *DIG ( b, n );
+	    for ( mask = 1 << ( NB - 1 ); mask; mask >>= 1 ) {
+	       if ( bigmul ( dx, dx, dx ) == Error )
+		  return Error;
+	       if ( nth_dig & mask )
+		  if ( bigmul ( dx, da, dx ) == Error )
+		     return Error;
+	       }
+	    }
+	 }
       return Succeeded;
       }
    else if (Type(*da) == T_Lrgint)    /* bignum ^ integer */
       return bigpowi(da, IntVal(*db), dx);
-   else if (Type(*db) == T_Lrgint)    /* integer ^ bignum */
-      return bigpowii(IntVal(*da), (word)bigtoreal(db), dx);
    else                               /* integer ^ integer */
       return bigpowii(IntVal(*da), IntVal(*db), dx);
 }
 
+int bigpowri( a, db, drslt )
+double a;
+dptr   db, drslt;
+{
+   register double retval;
+   register word n;
+   register DIGIT nth_dig, mask;
+   struct b_bignum *b;
+   word blen;
+
+   b = LrgInt ( db );
+   blen = LEN ( b );
+   if ( b->sign ) {
+      if ( a == 0.0 )
+	 ReturnErrNum(204, Error);
+      else
+	 a = 1.0 / a;
+      }
+
+   /* We scan the bits of b from the most to least significant.
+    * The bit position in b is represented by the pair ( n, mask )
+    * where n is the DIGIT number (0 = most sig.) and mask is the
+    * the bit mask for the current bit.
+    *
+    * For each bit (most sig to least) in b,
+    *  for each zero, square the partial result;
+    *  for each one, square it and multiply it by a */
+   retval = 1.0;
+   for ( n = 0; n < blen; ++n ) {
+      nth_dig = *DIG ( b, n );
+      for ( mask = 1 << ( NB - 1 ); mask; mask >>= 1 ) {
+	 retval *= retval;
+	 if ( nth_dig & mask )
+	    retval *= a;
+	 }
+      }
+
+   Protect(BlkLoc(*drslt) = (union block *)alcreal(retval), return Error);
+   drslt->dword = D_Real;
+   return Succeeded;
+}
+
 /*
  *  iand(da, db) -> dx
  */
@@ -999,7 +1071,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] & bd[i];
@@ -1043,7 +1115,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] & bd[i];
@@ -1087,7 +1159,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] & bd[i];
@@ -1149,7 +1221,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] | bd[i];
@@ -1193,7 +1265,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] | bd[i];
@@ -1237,7 +1309,7 @@ dptr da, db, dx;
          if (b->sign)
 	    compl1(bd, bd, xlen);
          }
-        
+
       for (i = 0; i < xlen; i++)
          *DIG(x,i) =
             ad[i] | bd[i];
@@ -1481,7 +1553,7 @@ dptr da, db;
 {
    struct b_bignum *a = LrgInt(da);
    struct b_bignum *b = LrgInt(db);
-   word alen, blen; 
+   word alen, blen;
 
    if (Type(*da) == T_Lrgint && Type(*db) == T_Lrgint) {
       if (a->sign != b->sign)
@@ -1508,7 +1580,7 @@ dptr da, db;
 
 /*
  *  ?da -> dx
- */  
+ */
 
 int bigrand(da, dx)
 dptr da, dx;
@@ -1528,7 +1600,7 @@ dptr da, dx;
       rval = RandVal;
       d[i] = rval * B;
       }
-    
+
    Protect(tu = alcbignum(alen + 2), return Error);
    Protect(tv = alcbignum(alen), return Error);
    if (div1(d, DIG(a,0),
@@ -1551,13 +1623,13 @@ static int bigaddi(da, i, dx)
 dptr da, dx;
 word i;
 {
-   tended struct b_bignum *a; 
-   struct b_bignum *x; 
-   word alen; 
+   tended struct b_bignum *a;
+   struct b_bignum *x;
+   word alen;
 
    if (i < 0 && i > MinLong)
       return bigsubi(da, -i, dx);
-   else if (i != (DIGIT)i) {
+   else if (i < 0 || i >= B ) {
       struct descrip td;
       char tdigits[INTBIGBLK];
 
@@ -1595,13 +1667,13 @@ static int bigsubi(da, i, dx)
 dptr da, dx;
 word i;
 {
-   tended struct b_bignum *a; 
-   struct b_bignum *x; 
+   tended struct b_bignum *a;
+   struct b_bignum *x;
    word alen;
 
    if (i < 0 && i > MinLong)
       return bigaddi(da, -i, dx);
-   else if (i != (DIGIT)i) {
+   else if (i < 0 || i >= B) {
       struct descrip td;
       char tdigits[INTBIGBLK];
 
@@ -1639,8 +1711,8 @@ static int bigmuli(da, i, dx)
 dptr da, dx;
 word i;
 {
-   tended struct b_bignum *a; 
-   struct b_bignum *x; 
+   tended struct b_bignum *a;
+   struct b_bignum *x;
    word alen;
 
    if (i <= -B || i >= B) {
@@ -1677,8 +1749,8 @@ static int bigdivi(da, i, dx)
 dptr da, dx;
 word i;
 {
-   tended struct b_bignum *a; 
-   struct b_bignum *x; 
+   tended struct b_bignum *a;
+   struct b_bignum *x;
    word alen;
 
    if (i <= -B || i >= B) {
@@ -1750,7 +1822,7 @@ dptr da, dx;
 word i;
 {
    int n = WordBits;
-   
+
    if (i > 0) {
       /* scan bits left to right.  skip leading 1. */
       while (--n >= 0)
@@ -1827,9 +1899,9 @@ dptr dx;
             else {
                itobig(x, (struct b_bignum *)tdigits, &td);
                if (bigmul(&td, &td, dx) == Error)
-   	          return Error;
+	          return Error;
                isbig = (Type(*dx) == T_Lrgint);
-               } 
+               }
             }
          if (i & ((word)1 << n)) {
             if (isbig) {
@@ -1843,7 +1915,7 @@ dptr dx;
                else {
                   itobig(x, (struct b_bignum *)tdigits, &td);
                   if (bigmuli(&td, a, dx) == Error)
-   		  return Error;
+		  return Error;
                   isbig = (Type(*dx) == T_Lrgint);
                   }
                }
@@ -1860,8 +1932,8 @@ dptr dx;
  *  negative if da < i
  *  zero if da == i
  *  positive if da > i
- */  
-  
+ */
+
 static word bigcmpi(da, i)
 dptr da;
 word i;
@@ -1905,7 +1977,7 @@ static DIGIT add1(u, v, w, n)
 DIGIT *u, *v, *w;
 word n;
 {
-   uword dig, carry; 
+   uword dig, carry;
    word i;
 
    carry = 0;
@@ -1927,7 +1999,7 @@ static word sub1(u, v, w, n)
 DIGIT *u, *v, *w;
 word n;
 {
-   uword dig, carry; 
+   uword dig, carry;
    word i;
 
    carry = 0;
@@ -1943,7 +2015,7 @@ word n;
  *  (u,n) * (v,m) -> (w,m+n)
  */
 
-static novalue mul1(u, v, w, n, m)
+static void mul1(u, v, w, n, m)
 DIGIT *u, *v, *w;
 word n, m;
 {
@@ -2008,7 +2080,7 @@ struct b_bignum *tu, *tv;
          qhat -= 1;
          rhat += v[0];
          }
-            
+
       /* D4 */
       carry = 0;
       for (i = n; i > 0; i--) {
@@ -2051,7 +2123,7 @@ struct b_bignum *tu, *tv;
  *
  */
 
-static novalue compl1(u, w, n)
+static void compl1(u, w, n)
 DIGIT *u, *w;
 word n;
 {
@@ -2095,7 +2167,7 @@ word n;
 {
    uword dig, carry;
    word i;
-    
+
    carry = k;
    for (i = n; --i >= 0; ) {
       dig = (uword)u[i] + carry;
@@ -2112,14 +2184,14 @@ word n;
  *  u must be greater than k
  */
 
-static novalue subi1(u, k, w, n)
+static void subi1(u, k, w, n)
 DIGIT *u, *w;
 word k;
 word n;
 {
    uword dig, carry;
    word i;
-    
+
    carry = -k;
    for (i = n; --i >= 0; ) {
       dig = (uword)u[i] + carry;
@@ -2181,7 +2253,7 @@ word n;
  *  ((u,n) << k) + c -> (w,n)
  *
  *  k in 0 .. NB-1
- *  c in 0 .. B-1 
+ *  c in 0 .. B-1
  *  returns carry, 0 .. B-1
  */
 
@@ -2197,7 +2269,7 @@ word n;
       bdcopy(u, w, n);
       return 0;
       }
-    
+
    for (i = n; --i >= 0; ) {
       dig = ((uword)u[i] << k) + c;
       w[i] = lo(dig);
@@ -2226,28 +2298,5 @@ word n;
       return 0;
    return u[n - 1] > (DIGIT)k ? 1 : -1;
 }
-
-#ifndef SysMem
-static novalue bdzero(dest, l)
-DIGIT *dest;
-word l;
-{
-   word i;
 
-   for (i = 0; i < l; i++)
-      dest[i] = 0;
-}
-
-static novalue bdcopy(src, dest, l)
-DIGIT *src, *dest;
-word l;
-{
-   word i;
-
-   for (i = 0; i < l; i++)
-      dest[i] = src[i];
-}
-#endif					/* SysMem */
-#else					/* LargeInts */
-static char x;			/* prevent empty module */
 #endif					/* LargeInts */
