@@ -4,10 +4,6 @@
  *   garbage collection, dump routines
  */
 
-#ifdef CRAY
-#include <malloc.h>
-#endif					/* CRAY */
-
 /*
  * Prototypes
  */
@@ -37,7 +33,7 @@ word coll_stat = 0;             /* collections in static region */
 word coll_str = 0;              /* collections in string region */
 word coll_blk = 0;              /* collections in block region */
 word coll_tot = 0;              /* total collections */
-#endif				/* MultiThread */
+#endif					/* MultiThread */
 word alcnum = 0;                /* co-expressions allocated since g.c. */
 
 dptr *quallist;                 /* string qualifier list */
@@ -45,12 +41,6 @@ dptr *qualfree;                 /* qualifier list free pointer */
 dptr *equallist;                /* end of qualifier list */
 
 int qualfail;                   /* flag: qualifier list overflow */
-
-/*
- *
- * Note: function calls beginning with "MM" are just empty macros
- * unless EventMon is defined.
- */
 
 /*
  * Allocated block size table (sizes given in bytes).  A size of -1 is used
@@ -102,9 +92,9 @@ int firstd[] = {
 
 #ifdef MultiThread
      8*WordSize,              /* T_Proc (6), procedure block */
-#else				/* MultiThread */
+#else					/* MultiThread */
      7*WordSize,              /* T_Proc (6), procedure block */
-#endif				/* MultiThread */
+#endif					/* MultiThread */
 
      4*WordSize,              /* T_Record (7), record block */
      0,                       /* T_List (8), list header block */
@@ -119,9 +109,9 @@ int firstd[] = {
 
 #if COMPILER
      2*WordSize,              /* T_Refresh (17), refresh block */
-#else				/* COMPILER */
+#else					/* COMPILER */
      (4+Wsizeof(struct pf_marker))*WordSize, /* T_Refresh (17), refresh block */
-#endif				/* COMPILER */
+#endif					/* COMPILER */
 
     -1,                       /* T_Coexpr (18), co-expression block */
      0,                       /* T_External (19), external block */
@@ -248,6 +238,14 @@ uword segsize[] = {
    ((uword)HSlots) << 8,		/* segment 9 */
    ((uword)HSlots) << 9,		/* segment 10 */
    ((uword)HSlots) << 10,		/* segment 11 */
+   ((uword)HSlots) << 11,		/* segment 12 */
+   ((uword)HSlots) << 12,		/* segment 13 */
+   ((uword)HSlots) << 13,		/* segment 14 */
+   ((uword)HSlots) << 14,		/* segment 15 */
+   ((uword)HSlots) << 15,		/* segment 16 */
+   ((uword)HSlots) << 16,		/* segment 17 */
+   ((uword)HSlots) << 17,		/* segment 18 */
+   ((uword)HSlots) << 18,		/* segment 19 */
    };
 
 /*
@@ -357,7 +355,7 @@ int region;
       case Strings:
          coll_str++;
          break;
-      case Blocks:  
+      case Blocks:
          coll_blk++;
          break;
       }
@@ -374,15 +372,6 @@ int region;
       return 0;
 #endif					/* !COMPILER */
 
-#if MACINTOSH
-#if MPW
-   {
-      void SetWatchCursor(void);
-      SetWatchCursor();
-      }
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
    /*
     * Sync the values (used by sweep) in the coexpr block for &current
     *  with the current values.
@@ -478,7 +467,7 @@ int region;
    { struct region *br;
    for (br = curblock->Gnext; br; br = br->Gnext) {
       char *source = br->base, *free = br->free;
-      uword NoMark = ~F_Mark;
+      uword NoMark = (uword) ~F_Mark;
       while (source < free) {
 	 BlkType(source) &= NoMark;
          source += BlkSize(source);
@@ -486,7 +475,7 @@ int region;
       }
    for (br = curblock->Gprev; br; br = br->Gprev) {
       char *source = br->base, *free = br->free;
-      uword NoMark = ~F_Mark;
+      uword NoMark = (uword) ~F_Mark;
       while (source < free) {
 	 BlkType(source) &= NoMark;
          source += BlkSize(source);
@@ -572,12 +561,7 @@ dptr dp;
    {
    char *newqual;
 
-#ifdef CRAY
-   if (strbase <= StrLoc(*dp) && StrLoc(*dp) < (strfree + 1)) {
-#else					/* CRAY */
-   if (InRange(strbase,StrLoc(*dp),strfree + 1)) { 
-#endif					/* CRAY */
-
+   if (InRange(strbase,StrLoc(*dp),strfree + 1)) {
       /*
        * The string is in the string space.  Add it to the string qualifier
        *  list, but before adding it, expand the string qualifier list if
@@ -586,7 +570,7 @@ dptr dp;
       if (qualfree >= equallist) {
 
 	 /* reallocate a new qualifier list that's twice as large */
-	 newqual = (char *)realloc((char *)quallist, (msize)(2 * qualsize));
+	 newqual = realloc(quallist, 2 * qualsize);
 	 if (newqual) {
 	    quallist = (dptr *)newqual;
 	    qualfree = (dptr *)(newqual + qualsize);
@@ -739,7 +723,7 @@ dptr dp;
          }
       if(BlkLoc(cp->freshblk) != NULL)
          markblock(&((struct b_coexpr *)block)->freshblk);
-#endif                                  /* Coexpr */
+#endif					/* Coexpr */
       }
 
    else {
@@ -1136,9 +1120,9 @@ static void cofree()
 
 #ifdef MultiThread
    rootpstate.Mainhead->title = T_Coexpr;
-#else				/* MultiThread */
+#else					/* MultiThread */
    BlkLoc(k_main)->coexpr.title = T_Coexpr;
-#endif				/* MultiThread */
+#endif					/* MultiThread */
 
    /*
     * The co-expression blocks are linked together through their
@@ -1161,12 +1145,9 @@ static void cofree()
             abp = abp->astk_nxt;
             free((pointer)xabp);
             }
-
-#ifdef CoProcesses
-         coswitch(BlkLoc(k_current)->coexpr.cstate, xep->cstate, -1);
-         /* terminate coproc for co-expression first */
-#endif					/* CoProcesses */
-
+         #ifdef CoClean
+	    coclean(xep->cstate);
+         #endif				/* CoClean */
          free((pointer)xep);
          }
       else {
@@ -1252,20 +1233,7 @@ word extra;
 static int qlcmp(q1,q2)
 dptr *q1, *q2;
    {
-
-#if IntBits == 16
-   long l;
-   l = (long)(DiffPtrs(StrLoc(**q1),StrLoc(**q2)));
-   if (l < 0)
-      return -1;
-   else if (l > 0)
-      return 1;
-   else
-      return 0;
-#else                                   /* IntBits = 16 */
    return (int)(DiffPtrs(StrLoc(**q1),StrLoc(**q2)));
-#endif                                  /* IntBits == 16 */
-
    }
 
 /*
@@ -1488,4 +1456,4 @@ void blkdump()
       }
    fprintf(stderr,"end of block region.\n");
    }
-#endif                                  /* DeBugIconx */
+#endif					/* DeBugIconx */
