@@ -16,24 +16,15 @@ wsp wstates = NULL;
 wbp wbndngs = NULL;
 int win_highwater = -1;
 
-#ifdef MacGraph
-#include "rmacrsc.ri"
-#endif					/* MacGraph */
-
 #ifdef XWindows
 #include "rxrsc.ri"
 #endif					/* XWindows */
 
-#ifdef PresentationManager
-#include "rpmrsc.ri"
-#endif					/* PresentationManager */
-
 /*
  * allocate a window binding structure
  */
 wbp alc_wbinding()
    {
-   int i;
    wbp w;
 
    GRFX_ALLOC(w, _wbinding);
@@ -44,7 +35,7 @@ wbp alc_wbinding()
 /*
  * free a window binding.
  */
-novalue free_binding(w)
+void free_binding(w)
 wbp w;
    {
    w->refcount--;
@@ -55,6 +46,4 @@ wbp w;
       }
    }
 
-#else					/* Graphics */
-static char x;			/* avoid empty module */
 #endif					/* Graphics */
